class HelpProvider(Component,IComponent,IDisposable,IExtenderProvider):
 """
 Provides pop-up or online Help for controls.

 

 HelpProvider()
 """
 def CanExtend(self,target):
  """
  CanExtend(self: HelpProvider,target: object) -> bool

  

   Specifies whether this object can provide its extender properties to the specified object.

  

   target: The object that the externder properties are provided to.

   Returns: true if this object can provide its extender properties; otherwise,false.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: Component,disposing: bool)

   Releases the unmanaged resources used by the System.ComponentModel.Component and optionally 

    releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def GetHelpKeyword(self,ctl):
  """
  GetHelpKeyword(self: HelpProvider,ctl: Control) -> str

  

   Returns the Help keyword for the specified control.

  

   ctl: A System.Windows.Forms.Control from which to retrieve the Help topic.

   Returns: The Help keyword associated with this control,or null if the System.Windows.Forms.HelpProvider 

    is currently configured to display the entire Help file or is configured to provide a Help 

    string.
  """
  pass
 def GetHelpNavigator(self,ctl):
  """
  GetHelpNavigator(self: HelpProvider,ctl: Control) -> HelpNavigator

  

   Returns the current System.Windows.Forms.HelpNavigator setting for the specified control.

  

   ctl: A System.Windows.Forms.Control from which to retrieve the Help navigator.

   Returns: The System.Windows.Forms.HelpNavigator setting for the specified control. The default is 

    System.Windows.Forms.HelpNavigator.AssociateIndex.
  """
  pass
 def GetHelpString(self,ctl):
  """
  GetHelpString(self: HelpProvider,ctl: Control) -> str

  

   Returns the contents of the pop-up Help window for the specified control.

  

   ctl: A System.Windows.Forms.Control from which to retrieve the Help string.

   Returns: The Help string associated with this control. The default is null.
  """
  pass
 def GetService(self,*args):
  """
  GetService(self: Component,service: Type) -> object

  

   Returns an object that represents a service provided by the System.ComponentModel.Component or 

    by its System.ComponentModel.Container.

  

  

   service: A service provided by the System.ComponentModel.Component.

   Returns: An System.Object that represents a service provided by the System.ComponentModel.Component,or 

    null if the System.ComponentModel.Component does not provide the specified service.
  """
  pass
 def GetShowHelp(self,ctl):
  """
  GetShowHelp(self: HelpProvider,ctl: Control) -> bool

  

   Returns a value indicating whether the specified control's Help should be displayed.

  

   ctl: A System.Windows.Forms.Control for which Help will be displayed.

   Returns: true if Help will be displayed for the control; otherwise,false.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def ResetShowHelp(self,ctl):
  """
  ResetShowHelp(self: HelpProvider,ctl: Control)

   Removes the Help associated with the specified control.

  

   ctl: The control to remove Help from.
  """
  pass
 def SetHelpKeyword(self,ctl,keyword):
  """
  SetHelpKeyword(self: HelpProvider,ctl: Control,keyword: str)

   Specifies the keyword used to retrieve Help when the user invokes Help for the specified control.

  

   ctl: A System.Windows.Forms.Control that specifies the control for which to set the Help topic.

   keyword: The Help keyword to associate with the control.
  """
  pass
 def SetHelpNavigator(self,ctl,navigator):
  """
  SetHelpNavigator(self: HelpProvider,ctl: Control,navigator: HelpNavigator)

   Specifies the Help command to use when retrieving Help from the Help file for the specified 

    control.

  

  

   ctl: A System.Windows.Forms.Control for which to set the Help keyword.

   navigator: One of the System.Windows.Forms.HelpNavigator values.
  """
  pass
 def SetHelpString(self,ctl,helpString):
  """
  SetHelpString(self: HelpProvider,ctl: Control,helpString: str)

   Specifies the Help string associated with the specified control.

  

   ctl: A System.Windows.Forms.Control with which to associate the Help string.

   helpString: The Help string associated with the control.
  """
  pass
 def SetShowHelp(self,ctl,value):
  """
  SetShowHelp(self: HelpProvider,ctl: Control,value: bool)

   Specifies whether Help is displayed for the specified control.

  

   ctl: A System.Windows.Forms.Control for which Help is turned on or off.

   value: true if Help displays for the control; otherwise,false.
  """
  pass
 def ToString(self):
  """
  ToString(self: HelpProvider) -> str

  

   Returns a string that represents the current System.Windows.Forms.HelpProvider.

   Returns: A string that represents the current System.Windows.Forms.HelpProvider.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __str__(self,*args):
  pass
 CanRaiseEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component can raise an event.



"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.ComponentModel.Component is currently in design mode.



"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this System.ComponentModel.Component.



"""

 HelpNamespace=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value specifying the name of the Help file associated with this System.Windows.Forms.HelpProvider object.



Get: HelpNamespace(self: HelpProvider) -> str



Set: HelpNamespace(self: HelpProvider)=value

"""

 Tag=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the object that contains supplemental data about the System.Windows.Forms.HelpProvider.



Get: Tag(self: HelpProvider) -> object



Set: Tag(self: HelpProvider)=value

"""





class ComConversionLossAttribute(Attribute,_Attribute):
 """
 Indicates that information was lost about a class or interface when it was imported from a type library to an assembly.

 

 ComConversionLossAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class ICustomFormatter:
 """ Defines a method that supports custom formatting of the value of an object. """
 def Format(self,format,arg,formatProvider):
  """
  Format(self: ICustomFormatter,format: str,arg: object,formatProvider: IFormatProvider) -> str

  

   Converts the value of a specified object to an equivalent string representation using specified 

    format and culture-specific formatting information.

  

  

   format: A format string containing formatting specifications.

   arg: An object to format.

   formatProvider: An object that supplies format information about the current instance.

   Returns: The string representation of the value of arg,formatted as specified by format and 

    formatProvider.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class DataErrorsChangedEventArgs(EventArgs):
 """ DataErrorsChangedEventArgs(propertyName: str) """
 @staticmethod
 def __new__(self,propertyName):
  """ __new__(cls: type,propertyName: str) """
  pass
 PropertyName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: PropertyName(self: DataErrorsChangedEventArgs) -> str



"""





class IAppDomainSetup:
 """ Represents assembly binding information that can be added to an instance of System.AppDomain. """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 ApplicationBase=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the directory containing the application.



Get: ApplicationBase(self: IAppDomainSetup) -> str



Set: ApplicationBase(self: IAppDomainSetup)=value

"""

 ApplicationName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the application.



Get: ApplicationName(self: IAppDomainSetup) -> str



Set: ApplicationName(self: IAppDomainSetup)=value

"""

 CachePath=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets and sets the name of an area specific to the application where files are shadow copied.



Get: CachePath(self: IAppDomainSetup) -> str



Set: CachePath(self: IAppDomainSetup)=value

"""

 ConfigurationFile=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets and sets the name of the configuration file for an application domain.



Get: ConfigurationFile(self: IAppDomainSetup) -> str



Set: ConfigurationFile(self: IAppDomainSetup)=value

"""

 DynamicBase=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the directory where dynamically generated files are stored and accessed.



Get: DynamicBase(self: IAppDomainSetup) -> str



Set: DynamicBase(self: IAppDomainSetup)=value

"""

 LicenseFile=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the location of the license file associated with this domain.



Get: LicenseFile(self: IAppDomainSetup) -> str



Set: LicenseFile(self: IAppDomainSetup)=value

"""

 PrivateBinPath=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the list of directories that is combined with the System.AppDomainSetup.ApplicationBase directory to probe for private assemblies.



Get: PrivateBinPath(self: IAppDomainSetup) -> str



Set: PrivateBinPath(self: IAppDomainSetup)=value

"""

 PrivateBinPathProbe=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the private binary directory path used to locate an application.



Get: PrivateBinPathProbe(self: IAppDomainSetup) -> str



Set: PrivateBinPathProbe(self: IAppDomainSetup)=value

"""

 ShadowCopyDirectories=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the names of the directories containing assemblies to be shadow copied.



Get: ShadowCopyDirectories(self: IAppDomainSetup) -> str



Set: ShadowCopyDirectories(self: IAppDomainSetup)=value

"""

 ShadowCopyFiles=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a string that indicates whether shadow copying is turned on or off.



Get: ShadowCopyFiles(self: IAppDomainSetup) -> str



Set: ShadowCopyFiles(self: IAppDomainSetup)=value

"""





class DataGridPreferredColumnWidthTypeConverter(TypeConverter):
 """
 Converts the value of an object to a different data type.

 

 DataGridPreferredColumnWidthTypeConverter()
 """
 def CanConvertFrom(self,*__args):
  """
  CanConvertFrom(self: DataGridPreferredColumnWidthTypeConverter,context: ITypeDescriptorContext,sourceType: Type) -> bool

  

   Gets a value that specifies whether the converter can convert an object in the given source type 

    to the native type of the converter.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   sourceType: A System.Type that represents the type you want to convert from.

   Returns: true,if this converter can perform the conversion; otherwise,false.
  """
  pass
 def ConvertFrom(self,*__args):
  """
  ConvertFrom(self: DataGridPreferredColumnWidthTypeConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object) -> object

  

   Converts the given object to the native type of the converter.

  

   context: An System.ComponentModel.ITypeDescriptorContext that a provides format context.

   culture: A System.Globalization.CultureInfo to use for the current culture.

   value: The System.Object to convert.

   Returns: An System.Object that represents the converted value.
  """
  pass
 def ConvertTo(self,*__args):
  """
  ConvertTo(self: DataGridPreferredColumnWidthTypeConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object,destinationType: Type) -> object

  

   Converts the given value to the native type of the converter.

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides format context.

   culture: A System.Globalization.CultureInfo to use for the current culture.

   value: The System.Object to convert.

   destinationType: The System.Type of the conversion.

   Returns: An System.Object that represents the converted value.
  """
  pass



class FileWebRequest(WebRequest,ISerializable):
 """ Provides a file system implementation of the System.Net.WebRequest class. """
 def Abort(self):
  """
  Abort(self: FileWebRequest)

   Cancels a request to an Internet resource.
  """
  pass
 def BeginGetRequestStream(self,callback,state):
  """
  BeginGetRequestStream(self: FileWebRequest,callback: AsyncCallback,state: object) -> IAsyncResult

  

   Begins an asynchronous request for a System.IO.Stream object to use to write data.

  

   callback: The System.AsyncCallback delegate.

   state: An object that contains state information for this request.

   Returns: An System.IAsyncResult that references the asynchronous request.
  """
  pass
 def BeginGetResponse(self,callback,state):
  """
  BeginGetResponse(self: FileWebRequest,callback: AsyncCallback,state: object) -> IAsyncResult

  

   Begins an asynchronous request for a file system resource.

  

   callback: The System.AsyncCallback delegate.

   state: An object that contains state information for this request.

   Returns: An System.IAsyncResult that references the asynchronous request.
  """
  pass
 def EndGetRequestStream(self,asyncResult):
  """
  EndGetRequestStream(self: FileWebRequest,asyncResult: IAsyncResult) -> Stream

  

   Ends an asynchronous request for a System.IO.Stream instance that the application uses to write 

    data.

  

  

   asyncResult: An System.IAsyncResult that references the pending request for a stream.

   Returns: A System.IO.Stream object that the application uses to write data.
  """
  pass
 def EndGetResponse(self,asyncResult):
  """
  EndGetResponse(self: FileWebRequest,asyncResult: IAsyncResult) -> WebResponse

  

   Ends an asynchronous request for a file system resource.

  

   asyncResult: An System.IAsyncResult that references the pending request for a response.

   Returns: A System.Net.WebResponse that contains the response from the file system resource.
  """
  pass
 def GetObjectData(self,*args):
  """
  GetObjectData(self: FileWebRequest,serializationInfo: SerializationInfo,streamingContext: StreamingContext)

   Populates a System.Runtime.Serialization.SerializationInfo with the data needed to serialize the 

    target object.

  

  

   serializationInfo: The System.Runtime.Serialization.SerializationInfo to populate with data.

   streamingContext: A System.Runtime.Serialization.StreamingContext  that specifies the destination for this 

    serialization.
  """
  pass
 def GetRequestStream(self):
  """
  GetRequestStream(self: FileWebRequest) -> Stream

  

   Returns a System.IO.Stream object for writing data to the file system resource.

   Returns: A System.IO.Stream for writing data to the file system resource.
  """
  pass
 def GetResponse(self):
  """
  GetResponse(self: FileWebRequest) -> WebResponse

  

   Returns a response to a file system request.

   Returns: A System.Net.WebResponse that contains the response from the file system resource.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """ __new__(cls: type,serializationInfo: SerializationInfo,streamingContext: StreamingContext) """
  pass
 def __reduce_ex__(self,*args):
  pass
 ConnectionGroupName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the connection group for the request. This property is reserved for future use.



Get: ConnectionGroupName(self: FileWebRequest) -> str



Set: ConnectionGroupName(self: FileWebRequest)=value

"""

 ContentLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the content length of the data being sent.



Get: ContentLength(self: FileWebRequest) -> Int64



Set: ContentLength(self: FileWebRequest)=value

"""

 ContentType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the content type of the data being sent. This property is reserved for future use.



Get: ContentType(self: FileWebRequest) -> str



Set: ContentType(self: FileWebRequest)=value

"""

 Credentials=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the credentials that are associated with this request. This property is reserved for future use.



Get: Credentials(self: FileWebRequest) -> ICredentials



Set: Credentials(self: FileWebRequest)=value

"""

 Headers=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection of the name/value pairs that are associated with the request. This property is reserved for future use.



Get: Headers(self: FileWebRequest) -> WebHeaderCollection



"""

 Method=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the protocol method used for the request. This property is reserved for future use.



Get: Method(self: FileWebRequest) -> str



Set: Method(self: FileWebRequest)=value

"""

 PreAuthenticate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether to preauthenticate a request. This property is reserved for future use.



Get: PreAuthenticate(self: FileWebRequest) -> bool



Set: PreAuthenticate(self: FileWebRequest)=value

"""

 Proxy=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the network proxy to use for this request. This property is reserved for future use.



Get: Proxy(self: FileWebRequest) -> IWebProxy



Set: Proxy(self: FileWebRequest)=value

"""

 RequestUri=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the Uniform Resource Identifier (URI) of the request.



Get: RequestUri(self: FileWebRequest) -> Uri



"""

 Timeout=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the length of time until the request times out.



Get: Timeout(self: FileWebRequest) -> int



Set: Timeout(self: FileWebRequest)=value

"""

 UseDefaultCredentials=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Always throws a System.NotSupportedException.



Get: UseDefaultCredentials(self: FileWebRequest) -> bool



Set: UseDefaultCredentials(self: FileWebRequest)=value

"""





"""Host application feature detectors."""
#pylint: disable=import-error,invalid-name,broad-except,superfluous-parens
from pyrevit import DB, UI

# check whether global parameters feature is available
GLOBAL_PARAMS = hasattr(DB, 'GlobalParametersManager')



class HttpListenerException(Win32Exception,ISerializable,_Exception):
 """
 The exception that is thrown when an error occurs processing an HTTP request.

 

 HttpListenerException()

 HttpListenerException(errorCode: int)

 HttpListenerException(errorCode: int,message: str)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,errorCode=None,message=None):
  """
  __new__(cls: type)

  __new__(cls: type,errorCode: int)

  __new__(cls: type,errorCode: int,message: str)

  __new__(cls: type,serializationInfo: SerializationInfo,streamingContext: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 ErrorCode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that identifies the error that occurred.



Get: ErrorCode(self: HttpListenerException) -> int



"""





from typing import Tuple, Set, Iterable, List


class ISelectionFilter:
    def AllowElement(self, elem: Element) -> bool: ...
    def AllowReference(self, reference: Reference, position: XYZ) -> bool: ...


class PickedBox:
    @property
    def Min(self) -> XYZ: ...
    @Min.setter
    def Min(self, __set_formal: XYZ) -> None: ...
    @property
    def Max(self) -> XYZ: ...
    @Max.setter
    def Max(self, __set_formal: XYZ) -> None: ...


class Selection:
    @overload
    def PickObject(self, objectType: ObjectType, selectionFilter: ISelectionFilter, statusPrompt: str) -> Reference: ...
    @overload
    def PickObject(self, objectType: ObjectType, selectionFilter: ISelectionFilter) -> Reference: ...
    @overload
    def PickObject(self, objectType: ObjectType, statusPrompt: str) -> Reference: ...
    @overload
    def PickObject(self, objectType: ObjectType) -> Reference: ...
    @overload
    def PickObjects(self, objectType: ObjectType, selectionFilter: ISelectionFilter, statusPrompt: str, pPreSelected: List[Reference]) -> List[Reference]: ...
    @overload
    def PickObjects(self, objectType: ObjectType, selectionFilter: ISelectionFilter, statusPrompt: str) -> List[Reference]: ...
    @overload
    def PickObjects(self, objectType: ObjectType, selectionFilter: ISelectionFilter) -> List[Reference]: ...
    @overload
    def PickObjects(self, objectType: ObjectType, statusPrompt: str) -> List[Reference]: ...
    @overload
    def PickObjects(self, objectType: ObjectType) -> List[Reference]: ...
    @overload
    def PickPoint(self, snapSettings: ObjectSnapTypes, statusPrompt: str) -> XYZ: ...
    @overload
    def PickPoint(self, statusPrompt: str) -> XYZ: ...
    @overload
    def PickPoint(self, snapSettings: ObjectSnapTypes) -> XYZ: ...
    @overload
    def PickPoint(self) -> XYZ: ...
    @overload
    def PickBox(self, style: PickBoxStyle, statusPrompt: str) -> PickedBox: ...
    @overload
    def PickBox(self, style: PickBoxStyle) -> PickedBox: ...
    @overload
    def PickElementsByRectangle(self, selectionFilter: ISelectionFilter, statusPrompt: str) -> List[Element]: ...
    @overload
    def PickElementsByRectangle(self, selectionFilter: ISelectionFilter) -> List[Element]: ...
    @overload
    def PickElementsByRectangle(self, statusPrompt: str) -> List[Element]: ...
    @overload
    def PickElementsByRectangle(self) -> List[Element]: ...
    @property
    def IsValidObject(self) -> bool: ...
    def SetElementIds(self, elementIds: ICollection) -> None: ...
    def GetElementIds(self) -> ICollection: ...
    def Dispose(self) -> None: ...


class ObjectType:
    Nothing = 0
    Element = 1
    PointOnElement = 2
    Edge = 3
    Face = 4
    LinkedElement = 5
    Subelement = 6


class ObjectSnapTypes:
    #None = 0
    Endpoints = 1
    Midpoints = 2
    Nearest = 4
    WorkPlaneGrid = 8
    Intersections = 16
    Centers = 32
    Perpendicular = 64
    Tangents = 128
    Quadrants = 256
    Points = 512


class PickBoxStyle:
    Crossing = 0
    Enclosing = 1
    Directional = 2


class SelectableInViewFilter(ElementSlowFilter):
    @overload
    def __init__(self, document: Document, viewId: ElementId, inverted: bool): ...
    @overload
    def __init__(self, document: Document, viewId: ElementId): ...



class DataGridBoolColumn(DataGridColumnStyle,IComponent,IDisposable,IDataGridColumnStyleEditingNotificationService):
 """
 Specifies a column in which each cell contains a check box for representing a Boolean value.

 

 DataGridBoolColumn()

 DataGridBoolColumn(prop: PropertyDescriptor)

 DataGridBoolColumn(prop: PropertyDescriptor,isDefault: bool)
 """
 def Abort(self,*args):
  """
  Abort(self: DataGridBoolColumn,rowNum: int)

   Initiates a request to interrupt an edit procedure.

  

   rowNum: The number of the row in which an operation is being interrupted.
  """
  pass
 def BeginUpdate(self,*args):
  """
  BeginUpdate(self: DataGridColumnStyle)

   Suspends the painting of the column until the System.Windows.Forms.DataGridColumnStyle.EndUpdate 

    method is called.
  """
  pass
 def CheckValidDataSource(self,*args):
  """
  CheckValidDataSource(self: DataGridColumnStyle,value: CurrencyManager)

   Throws an exception if the System.Windows.Forms.DataGrid does not have a valid data source,or 

    if this column is not mapped to a valid property in the data source.

  

  

   value: A System.Windows.Forms.CurrencyManager to check.
  """
  pass
 def ColumnStartedEditing(self,*args):
  """
  ColumnStartedEditing(self: DataGridColumnStyle,editingControl: Control)

   Informs the System.Windows.Forms.DataGrid that the user has begun editing the column.

  

   editingControl: The System.Windows.Forms.Control that hosted by the column.
  """
  pass
 def Commit(self,*args):
  """
  Commit(self: DataGridBoolColumn,dataSource: CurrencyManager,rowNum: int) -> bool

  

   Initiates a request to complete an editing procedure.

  

   dataSource: The System.Data.DataView of the edited column.

   rowNum: The number of the edited row.

   Returns: true if the editing procedure committed successfully; otherwise,false.
  """
  pass
 def ConcedeFocus(self,*args):
  """ ConcedeFocus(self: DataGridBoolColumn) """
  pass
 def CreateHeaderAccessibleObject(self,*args):
  """
  CreateHeaderAccessibleObject(self: DataGridColumnStyle) -> AccessibleObject

  

   Gets the System.Windows.Forms.AccessibleObject for the column.

   Returns: An System.Windows.Forms.AccessibleObject for the column.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: Component,disposing: bool)

   Releases the unmanaged resources used by the System.ComponentModel.Component and optionally 

    releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def Edit(self,*args):
  """
  Edit(self: DataGridBoolColumn,source: CurrencyManager,rowNum: int,bounds: Rectangle,readOnly: bool,displayText: str,cellIsVisible: bool)

   Prepares the cell for editing a value.

  

   source: The System.Data.DataView of the edited cell.

   rowNum: The row number of the edited cell.

   bounds: The System.Drawing.Rectangle in which the control is to be sited.

   readOnly: true if the value is read only; otherwise,false.

   displayText: The text to display in the cell.

   cellIsVisible: true to show the cell; otherwise,false.

  Edit(self: DataGridColumnStyle,source: CurrencyManager,rowNum: int,bounds: Rectangle,readOnly: bool,displayText: str)

   Prepares the cell for editing using the specified System.Windows.Forms.CurrencyManager,row 

    number,and System.Drawing.Rectangle parameters.

  

  

   source: The System.Windows.Forms.CurrencyManager for the System.Windows.Forms.DataGridColumnStyle.

   rowNum: The row number in this column which is being edited.

   bounds: The System.Drawing.Rectangle in which the control is to be sited.

   readOnly: A value indicating whether the column is a read-only. true if the value is read-only; otherwise,

    false.

  

   displayText: The text to display in the control.

  Edit(self: DataGridColumnStyle,source: CurrencyManager,rowNum: int,bounds: Rectangle,readOnly: bool)

   Prepares a cell for editing.

  

   source: The System.Windows.Forms.CurrencyManager for the System.Windows.Forms.DataGridColumnStyle.

   rowNum: The row number to edit.

   bounds: The bounding System.Drawing.Rectangle in which the control is to be sited.

   readOnly: A value indicating whether the column is a read-only. true if the value is read-only; otherwise,

    false.
  """
  pass
 def EndUpdate(self,*args):
  """
  EndUpdate(self: DataGridColumnStyle)

   Resumes the painting of columns suspended by calling the 

    System.Windows.Forms.DataGridColumnStyle.BeginUpdate method.
  """
  pass
 def EnterNullValue(self,*args):
  """
  EnterNullValue(self: DataGridBoolColumn)

   Enters a System.DBNull.Value into the column.
  """
  pass
 def GetColumnValueAtRow(self,*args):
  """
  GetColumnValueAtRow(self: DataGridBoolColumn,lm: CurrencyManager,row: int) -> object

  

   Gets the value at the specified row.

  

   lm: The System.Windows.Forms.CurrencyManager for the column.

   row: The row number.

   Returns: The value,typed as System.Object.
  """
  pass
 def GetMinimumHeight(self,*args):
  """
  GetMinimumHeight(self: DataGridBoolColumn) -> int

  

   Gets the height of a cell in a column.

   Returns: The height of the column. The default is 16.
  """
  pass
 def GetPreferredHeight(self,*args):
  """
  GetPreferredHeight(self: DataGridBoolColumn,g: Graphics,value: object) -> int

  

   Gets the height used when resizing columns.

  

   g: A System.Drawing.Graphics that draws on the screen.

   value: An System.Object that contains the value to be drawn to the screen.

   Returns: The height used to automatically resize cells in a column.
  """
  pass
 def GetPreferredSize(self,*args):
  """
  GetPreferredSize(self: DataGridBoolColumn,g: Graphics,value: object) -> Size

  

   Gets the optimum width and height of a cell given a specific value to contain.

  

   g: A System.Drawing.Graphics that draws the cell.

   value: The value that must fit in the cell.

   Returns: A System.Drawing.Size that contains the drawing information for the cell.
  """
  pass
 def GetService(self,*args):
  """
  GetService(self: Component,service: Type) -> object

  

   Returns an object that represents a service provided by the System.ComponentModel.Component or 

    by its System.ComponentModel.Container.

  

  

   service: A service provided by the System.ComponentModel.Component.

   Returns: An System.Object that represents a service provided by the System.ComponentModel.Component,or 

    null if the System.ComponentModel.Component does not provide the specified service.
  """
  pass
 def Invalidate(self,*args):
  """
  Invalidate(self: DataGridColumnStyle)

   Redraws the column and causes a paint message to be sent to the control.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def Paint(self,*args):
  """
  Paint(self: DataGridBoolColumn,g: Graphics,bounds: Rectangle,source: CurrencyManager,rowNum: int,backBrush: Brush,foreBrush: Brush,alignToRight: bool)

   Draws the System.Windows.Forms.DataGridBoolColumn with the given System.Drawing.Graphics,

    System.Drawing.Rectangle,row number,System.Drawing.Brush,and System.Drawing.Color.

  

  

   g: The System.Drawing.Graphics to draw to.

   bounds: The bounding System.Drawing.Rectangle to paint into.

   source: The System.Windows.Forms.CurrencyManager of the column.

   rowNum: The number of the row in the underlying data table being referred to.

   backBrush: A System.Drawing.Brush used to paint the background color.

   foreBrush: A System.Drawing.Color used to paint the foreground color.

   alignToRight: A value indicating whether to align the content to the right. true if the content is aligned to 

    the right,otherwise,false.

  

  Paint(self: DataGridBoolColumn,g: Graphics,bounds: Rectangle,source: CurrencyManager,rowNum: int,alignToRight: bool)

   Draws the System.Windows.Forms.DataGridBoolColumn with the given System.Drawing.Graphics,

    System.Drawing.Rectangle,row number,and alignment settings.

  

  

   g: The System.Drawing.Graphics to draw to.

   bounds: The bounding System.Drawing.Rectangle to paint into.

   source: The System.Windows.Forms.CurrencyManager of the column.

   rowNum: The number of the row in the underlying data table being referred to.

   alignToRight: A value indicating whether to align the content to the right. true if the content is aligned to 

    the right,otherwise,false.

  

  Paint(self: DataGridBoolColumn,g: Graphics,bounds: Rectangle,source: CurrencyManager,rowNum: int)

   Draws the System.Windows.Forms.DataGridBoolColumn with the given System.Drawing.Graphics,

    System.Drawing.Rectangle and row number.

  

  

   g: The System.Drawing.Graphics to draw to.

   bounds: The bounding System.Drawing.Rectangle to paint into.

   source: The System.Windows.Forms.CurrencyManager of the column.

   rowNum: The number of the row referred to in the underlying data.
  """
  pass
 def ReleaseHostedControl(self,*args):
  """
  ReleaseHostedControl(self: DataGridColumnStyle)

   Allows the column to free resources when the control it hosts is not needed.
  """
  pass
 def SetColumnValueAtRow(self,*args):
  """
  SetColumnValueAtRow(self: DataGridBoolColumn,lm: CurrencyManager,row: int,value: object)

   Sets the value of a specified row.

  

   lm: The System.Windows.Forms.CurrencyManager for the column.

   row: The row number.

   value: The value to set,typed as System.Object.
  """
  pass
 def SetDataGrid(self,*args):
  """
  SetDataGrid(self: DataGridColumnStyle,value: DataGrid)

   Sets the System.Windows.Forms.DataGrid control that this column belongs to.

  

   value: The System.Windows.Forms.DataGrid control that this column belongs to.
  """
  pass
 def SetDataGridInColumn(self,*args):
  """
  SetDataGridInColumn(self: DataGridColumnStyle,value: DataGrid)

   Sets the System.Windows.Forms.DataGrid for the column.

  

   value: A System.Windows.Forms.DataGrid.
  """
  pass
 def UpdateUI(self,*args):
  """
  UpdateUI(self: DataGridColumnStyle,source: CurrencyManager,rowNum: int,displayText: str)

   Updates the value of a specified row with the given text.

  

   source: The System.Windows.Forms.CurrencyManager associated with the 

    System.Windows.Forms.DataGridColumnStyle.

  

   rowNum: The row to update.

   displayText: The new value.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,prop=None,isDefault=None):
  """
  __new__(cls: type)

  __new__(cls: type,prop: PropertyDescriptor)

  __new__(cls: type,prop: PropertyDescriptor,isDefault: bool)
  """
  pass
 def __str__(self,*args):
  pass
 AllowNull=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether null values are allowed.



Get: AllowNull(self: DataGridBoolColumn) -> bool



Set: AllowNull(self: DataGridBoolColumn)=value

"""

 CanRaiseEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component can raise an event.



"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.ComponentModel.Component is currently in design mode.



"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this System.ComponentModel.Component.



"""

 FalseValue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the actual value used when setting the value of the column to false.



Get: FalseValue(self: DataGridBoolColumn) -> object



Set: FalseValue(self: DataGridBoolColumn)=value

"""

 FontHeight=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the height of the column's font.



"""

 NullValue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the actual value used when setting the value of the column to System.DBNull.Value.



Get: NullValue(self: DataGridBoolColumn) -> object



Set: NullValue(self: DataGridBoolColumn)=value

"""

 TrueValue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the actual value used when setting the value of the column to true.



Get: TrueValue(self: DataGridBoolColumn) -> object



Set: TrueValue(self: DataGridBoolColumn)=value

"""


 AllowNullChanged=None
 FalseValueChanged=None
 TrueValueChanged=None




class IWindowTarget:
 """ Defines the communication layer between a control and the Win32 API. """
 def OnHandleChange(self,newHandle):
  """
  OnHandleChange(self: IWindowTarget,newHandle: IntPtr)

   Sets the handle of the System.Windows.Forms.IWindowTarget to the specified handle.

  

   newHandle: The new handle of the System.Windows.Forms.IWindowTarget.
  """
  pass
 def OnMessage(self,m):
  """
  OnMessage(self: IWindowTarget,m: Message) -> Message

  

   Processes the Windows messages.

  

   m: The Windows message to process.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



from typing import Tuple, Set, Iterable, List


class gbXMLExportComplexity:
    Simple = 0
    SimpleWithShadingSurfaces = 1
    Complex = 2
    ComplexWithShadingSurfaces = 3
    ComplexWithMullionsAndShadingSurfaces = 4


class gbXMLBuildingType:
    AutomotiveFacility = 0
    ConventionCenter = 1
    Courthouse = 2
    DiningBarLoungeOrLeisure = 3
    DiningCafeteriaFastFood = 4
    DiningFamily = 5
    Dormitory = 6
    ExerciseCenter = 7
    FireStation = 8
    Gymnasium = 9
    HospitalOrHealthcare = 10
    Hotel = 11
    Library = 12
    Manufacturing = 13
    Motel = 14
    MotionPictureTheatre = 15
    MultiFamily = 16
    Museum = 17
    Office = 18
    ParkingGarage = 19
    Penitentiary = 20
    PerformingArtsTheater = 21
    PoliceStation = 22
    PostOffice = 23
    ReligiousBuilding = 24
    Retail = 25
    SchoolOrUniversity = 26
    SingleFamily = 27
    SportsArena = 28
    TownHall = 29
    Transportation = 30
    Warehouse = 31
    Workshop = 32
    NoOfBuildingTypes = 33
    CustomizeBuildingType = -2
    NoBuildingType = -1


class gbXMLServiceType:
    CentralHeatingRadiators = 0
    CentralHeatingConvectors = 1
    CentralHeatingRadiantFloor = 2
    CentralHeatingHotAir = 3
    OtherRoomHeater = 4
    RadiantHeaterFlue = 5
    RadiantHeaterNoFlue = 6
    RadiantHeaterMultiburner = 7
    ForcedConvectionHeaterFlue = 8
    ForcedConvectionHeaterNoFlue = 9
    VAVSingleDuct = 10
    VAVDualDuct = 11
    VAVIndoorPackagedCabinet = 12
    VAVTerminalReheat = 13
    FanCoilSystem = 14
    InductionSystem = 15
    ConstantVolumeFixedOA = 16
    ConstantVolumeVariableOA = 17
    ConstantVolumeTerminalReheat = 18
    MultizoneHotDeckColdDeck = 19
    ConstantVolumeDualDuct = 20
    RadiantCooledCeilings = 21
    ActiveChilledBeams = 22
    WaterLoopHeatPump = 23
    VariableRefrigerantFlow = 24
    SplitSystemsWithNaturalVentilation = 25
    SplitSystemsWithMechanicalVentilation = 26
    SplitSystemsWithMechanicalVentilationWithCooling = 27
    NoOfServiceTypes = 28
    NoServiceType = -1


class gbXMLConditionType:
    Heated = 0
    Cooled = 1
    HeatedAndCooled = 2
    Unconditioned = 3
    Vented = 4
    NaturallyVentedOnly = 5
    NoOfConditionTypes = 6
    NoConditionType = -1


class gbXMLSpaceType:
    ActiveStorage = 0
    ActiveStorageHospitalOrHealthcare = 1
    AirOrTrainOrBusBaggageArea = 2
    AirportConcourse = 3
    AtriumEachAdditionalFloor = 4
    AtriumFirstThreeFloors = 5
    AudienceOrSeatingAreaPenitentiary = 6
    AudienceOrSeatingAreaExerciseCenter = 7
    AudienceOrSeatingAreaGymnasium = 8
    AudienceOrSeatingAreaSportsArena = 9
    AudienceOrSeatingAreaConventionCenter = 10
    AudienceOrSeatingAreaMotionPictureTheatre = 11
    AudienceOrSeatingAreaPerformingArtsTheatre = 12
    AudienceOrSeatingAreaReligious = 13
    AudienceOrSeatingAreaPoliceOrFireStations = 14
    AudienceOrSeatingAreaCourtHouse = 15
    AudienceOrSeatingAreaAuditorium = 16
    BankCustomerArea = 17
    BankingActivityAreaOffice = 18
    BarberAndBeautyParlor = 19
    CardFileAndCataloguingLibrary = 20
    ClassroomOrLectureOrTrainingPenitentiary = 21
    ClassroomOrLectureOrTraining = 22
    ConfinementCellsPenitentiary = 23
    ConfinementCellsCourtHouse = 24
    ConferenceMeetingOrMultipurpose = 25
    CorridorOrTransition = 26
    CorridorOrTransitionManufacturingFacility = 27
    CorridorsWithPatientWaitingExamHospitalOrHealthcare = 28
    CourtSportsAreaSportsArena = 29
    CourtroomCourtHouse = 30
    DepartmentStoreSalesAreaRetail = 31
    DetailedManufacturingFacility = 32
    DiningArea = 33
    DiningAreaHotel = 34
    DiningAreaFamilyDining = 35
    DiningAreaLoungeOrLeisureDining = 36
    DiningAreaMotel = 37
    DiningAreaTransportation = 38
    DiningAreaPenitentiary = 39
    DiningAreaCivilServices = 40
    DormitoryBedroom = 41
    DormitoryStudyHall = 42
    DressingOrLockerOrFittingRoomGymnasium = 43
    DressingOrLockerOrFittingRoomCourtHouse = 44
    DressingOrLockerOrFittingRoomPerformingArtsTheatre = 45
    DressingOrLockerOrFittingRoomAuditorium = 46
    DressingOrLockerOrFittingRoomExerciseCenter = 47
    ElectricalOrMechanical = 48
    ElevatorLobbies = 49
    EmergencyHospitalOrHealthcare = 50
    EquipmentRoomManufacturingFacility = 51
    ExamOrTreatmentHospitalOrHealthcare = 52
    ExerciseAreaExerciseCenter = 53
    ExerciseAreaGymnasium = 54
    ExhibitSpaceConventionCenter = 55
    FellowshipHallReligiousBuildings = 56
    FineMaterialWarehouse = 57
    FineMerchandiseSalesAreaRetail = 58
    FireStationEngineRoomPoliceOrFireStation = 59
    FoodPreparation = 60
    GarageServiceOrRepairAutomotiveFacility = 61
    GeneralHighBayManufacturingFacility = 62
    GeneralLowBayManufacturingFacility = 63
    GeneralExhibitionMuseum = 64
    HospitalNurseryHospitalOrHealthcare = 65
    HospitalOrMedicalSuppliesHospitalOrHealthcare = 66
    HospitalOrRadiologyHospitalOrHealthcare = 67
    HotelOrConferenceCenterConferenceOrMeeting = 68
    InactiveStorage = 69
    JudgesChambersCourtHouse = 70
    LaboratoryOffice = 71
    LaundryIroningAndSorting = 72
    LaundryWashingHospitalOrHealthcare = 73
    LibraryAudioVisualLibraryAudioVisual = 74
    LivingQuartersDormitory = 75
    LivingQuartersMotel = 76
    LivingQuartersHotel = 77
    Lobby = 78
    LobbyReligiousBuildings = 79
    LobbyMotionPictureTheatre = 80
    LobbyAuditorium = 81
    LobbyPerformingArtsTheatre = 82
    LobbyPostOffice = 83
    LobbyHotel = 84
    LoungeOrRecreation = 85
    MallConcourseSalesAreaRetail = 86
    MassMerchandisingSalesAreaRetail = 87
    MediumOrBulkyMaterialWarehouse = 88
    MerchandisingSalesAreaRetail = 89
    MuseumAndGalleryStorage = 90
    NurseStationHospitalOrHealthcare = 91
    OfficeEnclosed = 92
    OfficeOpenPlan = 93
    OfficeCommonActivityAreasInactiveStorage = 94
    OperatingRoomHospitalOrHealthcare = 95
    OtherTelevisedPlayingAreaSportsArena = 96
    ParkingAreaAttendantOnlyParkingGarage = 97
    ParkingAreaPedestrianParkingGarage = 98
    PatientRoomHospitalOrHealthcare = 99
    PersonalServicesSalesAreaRetail = 100
    PharmacyHospitalOrHealthcare = 101
    PhysicalTherapyHospitalOrHealthcare = 102
    PlayingAreaGymnasium = 103
    Plenum = 104
    PoliceStationLaboratoryPoliceOrFireStations = 105
    PublicAndStaffLoungeHospitalOrHealthcare = 106
    ReadingAreaLibrary = 107
    ReceptionOrWaitingTransportation = 108
    ReceptionOrWaitingMotel = 109
    ReceptionOrWaitingHotel = 110
    RecoveryHospitalOrHealthcare = 111
    RestorationMuseum = 112
    Restrooms = 113
    RingSportsAreaSportsArena = 114
    SleepingQuartersPoliceOrFireStation = 115
    SortingAreaPostOffice = 116
    SpecialtyStoreSalesAreaRetail = 117
    StacksLibrary = 118
    StairsInactive = 119
    Stairway = 120
    SupermarketSalesAreaRetail = 121
    TerminalTicketCounterTransportation = 122
    WorkshopWorkshop = 123
    WorshipPulpitChoirReligious = 124
    NoOfSpaceTypes = 125
    CustomizeSpaceType = -2
    NoSpaceType = -1


class gbXMLSurfaceType:
    InteriorWall = 0
    ExteriorWall = 1
    Roof = 2
    InteriorFloor = 3
    Shade = 4
    UndergroundWall = 5
    UndergroundSlab = 6
    Ceiling = 7
    SurfaceAir = 8
    UndergroundCeiling = 9
    RaisedFloor = 10
    SlabOnGrade = 11
    NoOfSurfaceTypes = 12


class gbXMLOpeningType:
    FixedWindow = 0
    OperableWindow = 1
    FixedSkylight = 2
    OperableSkylight = 3
    SlidingDoor = 4
    NonSlidingDoor = 5
    OpeningAir = 6
    NoOfOpeningTypes = 7


class gbXMLBuildingOperatingSchedule:
    DefaultOperatingSchedule = 0
    TwentyFourHourSevenDayFacility = 1
    TwentyFourHourHourSixDayFacility = 2
    TwentyFourHourHourFiveDayFacility = 3
    TwelveHourSevenDayFacility = 4
    TwelveHourSixDayFacility = 5
    TwelveHourFiveDayFacility = 6
    KindergartenThruTwelveGradeSchool = 7
    YearRoundSchool = 8
    TheaterPerformingArts = 9
    Worship = 10
    NoOfOperatingScheduleEnums = 11


class gbXMLBuildingHVACSystem:
    TwelveSEERSPointNineAFUESplitPackagedGasFiveToElevenTon = 0
    ElevenPointThreeEERPackagedVAVEightyFourPointFourPercentBoilerHeating = 1
    CentralVAVHWHeatChillerFivePointNinetySixCOPBoilersEightyFourPoint5Eff = 2
    FourPipeFanCoilSystemChillerFivePointNinetySixCOPBoilersEightFourPointFiveEff = 3
    CentralVAVElectricResistanceHeatChillerFivePointNinetySixCOP = 4
    TwelveSEERSevenPointSevenHSPFSplitPackagedHeatPump = 5
    TwoPipeFanCoilSystemChillerFivePointNinetySixCOPBoilersEightyFourPointFiveEff = 6
    TwelveSEEREightPointThreeHSPFPackagedTerminalHeatPumpPTAC = 7
    ResidentialSeventeenSEERNinePointSixHSPFSplitHPLessThanFivePointFiveTon = 8
    UnderfloorAirDistribution = 9
    ResidentialFourteenSEERPointNineAFUESplitPackagedGasLessThanFivePointFiveTon = 10
    ResidentialFourteenSEEREightPointThreeHSPFSplitPackagedHeatPump = 11
    NoOfHVACSystemEnums = 12


class gbXMLExportBuildingEnvelope:
    UseFunctionParameter = 0
    IdentifyExteriorElements = 1


class HVACLoadType(Element):
    @property
    def AreaPerPerson(self) -> float: ...
    @AreaPerPerson.setter
    def AreaPerPerson(self, value: float) -> None: ...
    @property
    def SensibleHeatGainPerPerson(self) -> float: ...
    @SensibleHeatGainPerPerson.setter
    def SensibleHeatGainPerPerson(self, value: float) -> None: ...
    @property
    def LatentHeatGainPerPerson(self) -> float: ...
    @LatentHeatGainPerPerson.setter
    def LatentHeatGainPerPerson(self, value: float) -> None: ...
    @property
    def LightingLoadDensity(self) -> float: ...
    @LightingLoadDensity.setter
    def LightingLoadDensity(self, value: float) -> None: ...
    @property
    def PowerLoadDensity(self) -> float: ...
    @PowerLoadDensity.setter
    def PowerLoadDensity(self, value: float) -> None: ...
    @property
    def PlenumLighting(self) -> float: ...
    @PlenumLighting.setter
    def PlenumLighting(self, value: float) -> None: ...
    @property
    def OutdoorAirPerPerson(self) -> float: ...
    @OutdoorAirPerPerson.setter
    def OutdoorAirPerPerson(self, value: float) -> None: ...
    @property
    def OutdoorAirPerArea(self) -> float: ...
    @OutdoorAirPerArea.setter
    def OutdoorAirPerArea(self, value: float) -> None: ...
    @property
    def AirChangesPerHour(self) -> float: ...
    @AirChangesPerHour.setter
    def AirChangesPerHour(self, value: float) -> None: ...
    @property
    def OutdoorAirFlowStandard(self) -> OutdoorAirFlowStandard: ...
    @OutdoorAirFlowStandard.setter
    def OutdoorAirFlowStandard(self, eOutdoorAirFlowStandard: OutdoorAirFlowStandard) -> None: ...
    @property
    def HeatingSetPoint(self) -> float: ...
    @HeatingSetPoint.setter
    def HeatingSetPoint(self, value: float) -> None: ...
    @property
    def CoolingSetPoint(self) -> float: ...
    @CoolingSetPoint.setter
    def CoolingSetPoint(self, value: float) -> None: ...
    @property
    def HumidificationSetPoint(self) -> float: ...
    @HumidificationSetPoint.setter
    def HumidificationSetPoint(self, value: float) -> None: ...
    @property
    def DehumidificationSetPoint(self) -> float: ...
    @DehumidificationSetPoint.setter
    def DehumidificationSetPoint(self, value: float) -> None: ...


class HVACLoadSpaceType(HVACLoadType):
    @property
    def IsPlenum(self) -> bool: ...
    @property
    def SpaceTypeName(self) -> str: ...
    @SpaceTypeName.setter
    def SpaceTypeName(self, name: str) -> None: ...
    def Create(document: Document, name: str) -> HVACLoadSpaceType: ...
    @overload
    def IsNameUnique(self, name: str) -> bool: ...
    @overload
    def IsNameUnique(document: Document, name: str) -> bool: ...


class HVACLoadBuildingType(HVACLoadType):
    @property
    def BuildingTypeName(self) -> str: ...
    @BuildingTypeName.setter
    def BuildingTypeName(self, name: str) -> None: ...
    @property
    def OpeningTime(self) -> str: ...
    @OpeningTime.setter
    def OpeningTime(self, value: str) -> None: ...
    @property
    def ClosingTime(self) -> str: ...
    @ClosingTime.setter
    def ClosingTime(self, value: str) -> None: ...
    @property
    def UnoccupiedCoolingSetPoint(self) -> float: ...
    @UnoccupiedCoolingSetPoint.setter
    def UnoccupiedCoolingSetPoint(self, value: float) -> None: ...
    def Create(document: Document, name: str) -> HVACLoadBuildingType: ...
    @overload
    def IsNameUnique(self, name: str) -> bool: ...
    @overload
    def IsNameUnique(document: Document, name: str) -> bool: ...
    def IsValidTime(hourMinute: str) -> bool: ...


class OutdoorAirFlowStandard:
    ByPeopleAndByArea = 0
    ByACH = 1
    MaxByPeople_ByArea = 2
    MaxByACH_ByPeopleByArea = 3
    MaxByACH_ByArea_ByPeople = 4


class ConstructionType:
    ExteriorWall = 0
    InteriorWall = 1
    Slab = 2
    Roof = 3
    Ceiling = 4
    Floor = 5
    Door = 6
    ExteriorWindow = 7
    InteriorWindow = 8
    Skylight = 9


class HVACLoadConstructionClass:
    LooseConstruction = 0
    MediumConstruction = 1
    TightConstruction = 2
    NoneConstruction = 3


class HVACLoadLoadsReportType:
    NoReport = 0
    SimpleReport = 1
    StandardReport = 2
    DetailedReport = 3


class AnalysisDisplayLegend(Element):
    @property
    def Height(self) -> float: ...
    @Height.setter
    def Height(self, height: float) -> None: ...


class AnalysisDisplayColorEntry:
    @overload
    def __init__(self, color: Color): ...
    @overload
    def __init__(self, color: Color, value: float): ...
    @overload
    def __init__(self): ...
    @property
    def Value(self) -> float: ...
    @property
    def Color(self) -> Color: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsEqual(self, other: AnalysisDisplayColorEntry) -> bool: ...
    def HasValue(self) -> bool: ...
    def Dispose(self) -> None: ...


class AnalysisDisplayColorSettings:
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: AnalysisDisplayColorSettings): ...
    @property
    def MaxColor(self) -> Color: ...
    @MaxColor.setter
    def MaxColor(self, color: Color) -> None: ...
    @property
    def MinColor(self) -> Color: ...
    @MinColor.setter
    def MinColor(self, color: Color) -> None: ...
    @property
    def ColorSettingsType(self) -> AnalysisDisplayStyleColorSettingsType: ...
    @ColorSettingsType.setter
    def ColorSettingsType(self, colorSettingsType: AnalysisDisplayStyleColorSettingsType) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetIntermediateColors(self) -> List[AnalysisDisplayColorEntry]: ...
    def AreIntermediateColorsValid(self, map: List[AnalysisDisplayColorEntry]) -> bool: ...
    def SetIntermediateColors(self, map: List[AnalysisDisplayColorEntry]) -> None: ...
    def Colors(self) -> int: ...
    def IsEqual(self, other: AnalysisDisplayColorSettings) -> bool: ...
    def Dispose(self) -> None: ...


class AnalysisDisplayLegendSettings:
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: AnalysisDisplayLegendSettings): ...
    @property
    def TextTypeId(self) -> ElementId: ...
    @TextTypeId.setter
    def TextTypeId(self, textTypeId: ElementId) -> None: ...
    @property
    def HeadingTextTypeId(self) -> ElementId: ...
    @HeadingTextTypeId.setter
    def HeadingTextTypeId(self, headingTextTypeId: ElementId) -> None: ...
    @property
    def ShowLegend(self) -> bool: ...
    @ShowLegend.setter
    def ShowLegend(self, showLegend: bool) -> None: ...
    @property
    def ShowUnits(self) -> bool: ...
    @ShowUnits.setter
    def ShowUnits(self, showUnits: bool) -> None: ...
    @property
    def ShowDataName(self) -> bool: ...
    @ShowDataName.setter
    def ShowDataName(self, showDataName: bool) -> None: ...
    @property
    def ShowDataDescription(self) -> bool: ...
    @ShowDataDescription.setter
    def ShowDataDescription(self, showDataDescription: bool) -> None: ...
    @property
    def Rounding(self) -> float: ...
    @Rounding.setter
    def Rounding(self, rounding: float) -> None: ...
    @property
    def NumberOfSteps(self) -> int: ...
    @NumberOfSteps.setter
    def NumberOfSteps(self, numberOfSteps: int) -> None: ...
    @property
    def ColorRangeWidth(self) -> int: ...
    @ColorRangeWidth.setter
    def ColorRangeWidth(self, colorRangeWidth: int) -> None: ...
    @property
    def ColorRangeHeight(self) -> int: ...
    @ColorRangeHeight.setter
    def ColorRangeHeight(self, colorRangeHeight: int) -> None: ...
    @property
    def ScaleHeight(self) -> int: ...
    @ScaleHeight.setter
    def ScaleHeight(self, scaleHeight: int) -> None: ...
    @property
    def NumberForScale(self) -> float: ...
    @NumberForScale.setter
    def NumberForScale(self, numberForScale: float) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsEqual(self, other: AnalysisDisplayLegendSettings) -> bool: ...
    def Dispose(self) -> None: ...


class AnalysisDisplayColoredSurfaceSettings:
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: AnalysisDisplayColoredSurfaceSettings): ...
    @property
    def ShowGridLines(self) -> bool: ...
    @ShowGridLines.setter
    def ShowGridLines(self, showGridLines: bool) -> None: ...
    @property
    def ShowContourLines(self) -> bool: ...
    @ShowContourLines.setter
    def ShowContourLines(self, showContourLines: bool) -> None: ...
    @property
    def GridColor(self) -> Color: ...
    @GridColor.setter
    def GridColor(self, color: Color) -> None: ...
    @property
    def GridLineWeight(self) -> int: ...
    @GridLineWeight.setter
    def GridLineWeight(self, lineWeight: int) -> None: ...
    @property
    def Transparency(self) -> int: ...
    @Transparency.setter
    def Transparency(self, transparency: int) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsEqual(self, other: AnalysisDisplayColoredSurfaceSettings) -> bool: ...
    def Dispose(self) -> None: ...


class AnalysisDisplayMarkersAndTextSettings:
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: AnalysisDisplayMarkersAndTextSettings): ...
    @property
    def TextTypeId(self) -> ElementId: ...
    @TextTypeId.setter
    def TextTypeId(self, textTypeId: ElementId) -> None: ...
    @property
    def MarkerType(self) -> AnalysisDisplayStyleMarkerType: ...
    @MarkerType.setter
    def MarkerType(self, markerType: AnalysisDisplayStyleMarkerType) -> None: ...
    @property
    def TextLabelType(self) -> AnalysisDisplayStyleMarkerTextLabelType: ...
    @TextLabelType.setter
    def TextLabelType(self, textLabelType: AnalysisDisplayStyleMarkerTextLabelType) -> None: ...
    @property
    def MarkerSize(self) -> float: ...
    @MarkerSize.setter
    def MarkerSize(self, markerSize: float) -> None: ...
    @property
    def Rounding(self) -> float: ...
    @Rounding.setter
    def Rounding(self, rounding: float) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsEqual(self, other: AnalysisDisplayMarkersAndTextSettings) -> bool: ...
    def Dispose(self) -> None: ...


class AnalysisDisplayDiagramSettings:
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: AnalysisDisplayDiagramSettings): ...
    @property
    def TextTypeId(self) -> ElementId: ...
    @TextTypeId.setter
    def TextTypeId(self, textTypeId: ElementId) -> None: ...
    @property
    def FenceType(self) -> AnalysisDisplayStyleDiagramFenceType: ...
    @FenceType.setter
    def FenceType(self, fenceType: AnalysisDisplayStyleDiagramFenceType) -> None: ...
    @property
    def TextLabelType(self) -> AnalysisDisplayStyleDiagramTextLabelType: ...
    @TextLabelType.setter
    def TextLabelType(self, textLabelType: AnalysisDisplayStyleDiagramTextLabelType) -> None: ...
    @property
    def Rounding(self) -> float: ...
    @Rounding.setter
    def Rounding(self, rounding: float) -> None: ...
    @property
    def Transparency(self) -> int: ...
    @Transparency.setter
    def Transparency(self, transparency: int) -> None: ...
    @property
    def OutlineColor(self) -> Color: ...
    @OutlineColor.setter
    def OutlineColor(self, color: Color) -> None: ...
    @property
    def OutlineLineWeight(self) -> int: ...
    @OutlineLineWeight.setter
    def OutlineLineWeight(self, lineWeight: int) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsEqual(self, other: AnalysisDisplayDiagramSettings) -> bool: ...
    def Dispose(self) -> None: ...


class AnalysisDisplayVectorSettings:
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: AnalysisDisplayVectorSettings): ...
    @property
    def TextTypeId(self) -> ElementId: ...
    @TextTypeId.setter
    def TextTypeId(self, textTypeId: ElementId) -> None: ...
    @property
    def VectorTextType(self) -> AnalysisDisplayStyleVectorTextType: ...
    @VectorTextType.setter
    def VectorTextType(self, vectorTextType: AnalysisDisplayStyleVectorTextType) -> None: ...
    @property
    def ArrowheadScale(self) -> AnalysisDisplayStyleVectorArrowheadScale: ...
    @ArrowheadScale.setter
    def ArrowheadScale(self, arrowheadScale: AnalysisDisplayStyleVectorArrowheadScale) -> None: ...
    @property
    def VectorPosition(self) -> AnalysisDisplayStyleVectorPosition: ...
    @VectorPosition.setter
    def VectorPosition(self, vectorPosition: AnalysisDisplayStyleVectorPosition) -> None: ...
    @property
    def VectorOrientation(self) -> AnalysisDisplayStyleVectorOrientation: ...
    @VectorOrientation.setter
    def VectorOrientation(self, vectorOrientation: AnalysisDisplayStyleVectorOrientation) -> None: ...
    @property
    def Rounding(self) -> float: ...
    @Rounding.setter
    def Rounding(self, rounding: float) -> None: ...
    @property
    def ArrowLineWeight(self) -> int: ...
    @ArrowLineWeight.setter
    def ArrowLineWeight(self, lineWeight: int) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsEqual(self, other: AnalysisDisplayVectorSettings) -> bool: ...
    def Dispose(self) -> None: ...


class AnalysisDisplayDeformedShapeSettings:
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: AnalysisDisplayDeformedShapeSettings): ...
    @property
    def ShowGridLines(self) -> bool: ...
    @ShowGridLines.setter
    def ShowGridLines(self, showGridLines: bool) -> None: ...
    @property
    def ShowContourLines(self) -> bool: ...
    @ShowContourLines.setter
    def ShowContourLines(self, showContourLines: bool) -> None: ...
    @property
    def TextTypeId(self) -> ElementId: ...
    @TextTypeId.setter
    def TextTypeId(self, textTypeId: ElementId) -> None: ...
    @property
    def TextLabelType(self) -> AnalysisDisplayStyleDeformedShapeTextLabelType: ...
    @TextLabelType.setter
    def TextLabelType(self, textLabelType: AnalysisDisplayStyleDeformedShapeTextLabelType) -> None: ...
    @property
    def Rounding(self) -> float: ...
    @Rounding.setter
    def Rounding(self, rounding: float) -> None: ...
    @property
    def GridColor(self) -> Color: ...
    @GridColor.setter
    def GridColor(self, color: Color) -> None: ...
    @property
    def GridLineWeight(self) -> int: ...
    @GridLineWeight.setter
    def GridLineWeight(self, lineWeight: int) -> None: ...
    @property
    def Transparency(self) -> int: ...
    @Transparency.setter
    def Transparency(self, transparency: int) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsEqual(self, other: AnalysisDisplayDeformedShapeSettings) -> bool: ...
    def Dispose(self) -> None: ...


class AnalysisDisplayStyle(Element):
    @overload
    def CreateAnalysisDisplayStyle(document: Document, name: str, deformedShapeSettings: AnalysisDisplayDeformedShapeSettings, colorSettings: AnalysisDisplayColorSettings, legendSettings: AnalysisDisplayLegendSettings) -> AnalysisDisplayStyle: ...
    @overload
    def CreateAnalysisDisplayStyle(document: Document, name: str, vectorSettings: AnalysisDisplayVectorSettings, colorSettings: AnalysisDisplayColorSettings, legendSettings: AnalysisDisplayLegendSettings) -> AnalysisDisplayStyle: ...
    @overload
    def CreateAnalysisDisplayStyle(document: Document, name: str, diagramSettings: AnalysisDisplayDiagramSettings, colorSettings: AnalysisDisplayColorSettings, legendSettings: AnalysisDisplayLegendSettings) -> AnalysisDisplayStyle: ...
    @overload
    def CreateAnalysisDisplayStyle(document: Document, name: str, markersAndTextSettings: AnalysisDisplayMarkersAndTextSettings, colorSettings: AnalysisDisplayColorSettings, legendSettings: AnalysisDisplayLegendSettings) -> AnalysisDisplayStyle: ...
    @overload
    def CreateAnalysisDisplayStyle(document: Document, name: str, coloredSurfaceSettings: AnalysisDisplayColoredSurfaceSettings, colorSettings: AnalysisDisplayColorSettings, legendSettings: AnalysisDisplayLegendSettings) -> AnalysisDisplayStyle: ...
    def GetElements(document: Document) -> ICollection: ...
    def FindByName(document: Document, name: str) -> ElementId: ...
    def SetName(self, name: str) -> None: ...
    def IsNameUnique(document: Document, name: str, excludedElement: AnalysisDisplayStyle) -> bool: ...
    def GetColorSettings(self) -> AnalysisDisplayColorSettings: ...
    def SetColorSettings(self, colorSettings: AnalysisDisplayColorSettings) -> None: ...
    def GetLegendSettings(self) -> AnalysisDisplayLegendSettings: ...
    def SetLegendSettings(self, legendSettings: AnalysisDisplayLegendSettings) -> None: ...
    def HasColoredSurfaceSettings(self) -> bool: ...
    def GetColoredSurfaceSettings(self) -> AnalysisDisplayColoredSurfaceSettings: ...
    def SetColoredSurfaceSettings(self, coloredSurfaceSettings: AnalysisDisplayColoredSurfaceSettings) -> None: ...
    def HasMarkersAndTextSettings(self) -> bool: ...
    def GetMarkersAndTextSettings(self) -> AnalysisDisplayMarkersAndTextSettings: ...
    def SetMarkersAndTextSettings(self, markersAndTextSettings: AnalysisDisplayMarkersAndTextSettings) -> None: ...
    def HasDiagramSettings(self) -> bool: ...
    def GetDiagramSettings(self) -> AnalysisDisplayDiagramSettings: ...
    def SetDiagramSettings(self, diagramSettings: AnalysisDisplayDiagramSettings) -> None: ...
    def HasVectorSettings(self) -> bool: ...
    def GetVectorSettings(self) -> AnalysisDisplayVectorSettings: ...
    def SetVectorSettings(self, vectorSettings: AnalysisDisplayVectorSettings) -> None: ...
    def HasDeformedShapeSettings(self) -> bool: ...
    def GetDeformedShapeSettings(self) -> AnalysisDisplayDeformedShapeSettings: ...
    def SetDeformedShapeSettings(self, deformedShapeSettings: AnalysisDisplayDeformedShapeSettings) -> None: ...
    def IsTextTypeIdValid(textTypeId: ElementId, doc: Document) -> bool: ...


class AnalysisResultSchema:
    @overload
    def __init__(self, name: str, description: str): ...
    @overload
    def __init__(self, other: AnalysisResultSchema): ...
    @property
    def Name(self) -> str: ...
    @Name.setter
    def Name(self, name: str) -> None: ...
    @property
    def Description(self) -> str: ...
    @Description.setter
    def Description(self, description: str) -> None: ...
    @property
    def AnalysisDisplayStyleId(self) -> ElementId: ...
    @AnalysisDisplayStyleId.setter
    def AnalysisDisplayStyleId(self, analysisDisplayStyleId: ElementId) -> None: ...
    @property
    def IsVisible(self) -> bool: ...
    @IsVisible.setter
    def IsVisible(self, isVisible: bool) -> None: ...
    @property
    def CurrentUnits(self) -> int: ...
    @CurrentUnits.setter
    def CurrentUnits(self, currentUnits: int) -> None: ...
    @property
    def Scale(self) -> float: ...
    @Scale.setter
    def Scale(self, scale: float) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsEqual(self, other: AnalysisResultSchema) -> bool: ...
    def SetUnits(self, names: List[str], multipliers: List[float]) -> None: ...
    def GetNumberOfUnits(self) -> int: ...
    def GetUnitsName(self, index: int) -> str: ...
    def GetUnitsMultiplier(self, index: int) -> float: ...
    def Dispose(self) -> None: ...


class AnalysisDisplayStyleColorSettingsType:
    GradientColor = 0
    SolidColorRanges = 1


class AnalysisDisplayStyleMarkerType:
    Circle = 0
    Square = 1
    Triangle = 2


class AnalysisDisplayStyleMarkerTextLabelType:
    ShowAll = 0
    ShowNone = 1
    ShowPredefined = 2


class AnalysisDisplayStyleDiagramFenceType:
    ShowAll = 0
    ShowNone = 1
    ShowPredefined = 2


class AnalysisDisplayStyleDiagramTextLabelType:
    ShowAll = 0
    ShowNone = 1
    ShowPredefined = 2


class AnalysisDisplayStyleVectorTextType:
    ShowAll = 0
    ShowNone = 1
    ShowPredefined = 2


class AnalysisDisplayStyleVectorArrowheadScale:
    NoScaling = 0
    Length5Percent = 1
    Length10Percent = 2
    Length15Percent = 3
    Length20Percent = 4
    NoArrow = 5


class AnalysisDisplayStyleVectorPosition:
    ToDataPoint = 0
    FromDataPoint = 1


class AnalysisDisplayStyleVectorOrientation:
    Linear = 0
    ArcAroundVectorAxis = 1


class AnalysisDisplayStyleDeformedShapeTextLabelType:
    ShowAll = 0
    ShowNone = 1
    ShowPredefined = 2


class BuildingEnvelopeAnalyzerOptions:
    def __init__(self): ...
    @property
    def AnalyzeEnclosedSpaceVolumes(self) -> bool: ...
    @AnalyzeEnclosedSpaceVolumes.setter
    def AnalyzeEnclosedSpaceVolumes(self, analyzeEnclosedSpaceVolumes: bool) -> None: ...
    @property
    def OptimizeGridCellSize(self) -> bool: ...
    @OptimizeGridCellSize.setter
    def OptimizeGridCellSize(self, optimizeGridCellSize: bool) -> None: ...
    @property
    def GridCellSize(self) -> float: ...
    @GridCellSize.setter
    def GridCellSize(self, gridCellSize: float) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class BuildingEnvelopeAnalyzer:
    @property
    def IsValidObject(self) -> bool: ...
    def Create(document: Document, options: BuildingEnvelopeAnalyzerOptions) -> BuildingEnvelopeAnalyzer: ...
    def GetBoundingElements(self) -> List[LinkElementId]: ...
    def GetBoundingElementsForSpaceVolume(self, spaceVolume: int) -> List[LinkElementId]: ...
    def GetCenterPointsForConnectedGridCellsInSpaceVolume(self, spaceVolume: int) -> List[XYZ]: ...
    def Dispose(self) -> None: ...


class ConceptualConstructionType(ElementType):
    @property
    def MaterialId(self) -> ElementId: ...
    @MaterialId.setter
    def MaterialId(self, materialId: ElementId) -> None: ...
    @property
    def MassSurfaceSubCategoryId(self) -> ElementId: ...
    def GetWallConstructionType(ccda: Document, typeEnum: ConceptualConstructionWallType) -> ElementId: ...
    def GetRoofConstructionType(ccda: Document, typeEnum: ConceptualConstructionRoofType) -> ElementId: ...
    def GetFloorOrSlabConstructionType(ccda: Document, typeEnum: ConceptualConstructionFloorSlabType) -> ElementId: ...
    def GetWindowOrSkylightConstructionType(ccda: Document, typeEnum: ConceptualConstructionWindowSkylightType) -> ElementId: ...
    def GetShadeConstructionType(ccda: Document, typeEnum: ConceptualConstructionShadeType) -> ElementId: ...
    def GetOpeningConstructionType(ccda: Document, typeEnum: ConceptualConstructionOpeningType) -> ElementId: ...
    def GetAllConceptualConstructionsForCategory(ccda: Document, massSubCategoryId: ElementId) -> ICollection: ...
    def IsValidConceptualConstructionId(ccda: Document, constructionTypeId: ElementId) -> bool: ...
    def IsValidSurfaceSubcategoryForConstruction(self, massSurfaceSubcategoryId: ElementId) -> bool: ...
    def IsValidConceptualConstructionIdForCategory(ccda: Document, constructionTypeId: ElementId, massSubcategoryId: ElementId) -> bool: ...
    def GetGBSId(self, massSurfaceSubCategoryId: ElementId) -> int: ...
    def IsValidSubcategoryForMassSurfaceDatas(massSubCategoryId: ElementId) -> bool: ...


class ConceptualSurfaceType(Element):
    @property
    def MassSubCategoryId(self) -> ElementId: ...
    @property
    def DefaultConstructionTypeId(self) -> ElementId: ...
    @DefaultConstructionTypeId.setter
    def DefaultConstructionTypeId(self, defaultConstructionTypeId: ElementId) -> None: ...
    def GetByMassSubCategoryId(cda: Document, massSubCategoryId: ElementId) -> ConceptualSurfaceType: ...
    def GetAllMassSubCategoryIds() -> List[ElementId]: ...
    def GetConstructionTypeIds(self) -> ICollection: ...


class ConceptualConstructionWallType:
    LightweightConstructionHighInsulation = 0
    LightweightConstructionTypicalColdClimateInsulation = 1
    LightweightConstructionTypicalMildClimateInsulation = 2
    LightweightConstructionLowInsulation = 3
    LightweightConstructionNoInsulationInterior = 4
    HighMassConstructionHighInsulation = 5
    HighMassConstructionTypicalColdClimateInsulation = 6
    HighMassConstructionTypicalMildClimateInsulation = 7
    HighMassConstructionNoInsulationInterior = 8
    NumWallTypeConstruction = 9
    InvalidExteriorWallTypeConstruction = -1


class ConceptualConstructionRoofType:
    HighInsulationCoolRoof = 0
    HighInsulationDarkRoof = 1
    TypicalInsulationCoolRoof = 2
    TypicalInsulationDarkRoof = 3
    LowInsulationCoolRoof = 4
    LowInsulationDarkRoof = 5
    NoInsulationDarkRoof = 6
    NumRoofTypeConstruction = 7
    InvalidRoofTypeConstruction = -1


class ConceptualConstructionFloorSlabType:
    LightweightConstructionHighInsulation = 0
    LightweightConstructionTypicalInsulation = 1
    LightweightConstructionLowInsulation = 2
    LightweightConstructionNoInsulationInterior = 3
    HighMassConstructionFrigidClimateSlabInsulation = 4
    HighMassConstructionColdClimateSlabInsulation = 5
    HighMassConstructionTypicalNoInsulation = 6
    NumFloorSlabTypeConstruction = 7
    InvalidFloorSlabTypeConstruction = -1


class ConceptualConstructionWindowSkylightType:
    SinglePaneClearNoCoating = 0
    SinglePaneTinted = 1
    SinglePaneReflective = 2
    DoublePaneClearNoCoating = 3
    DoublePaneTinted = 4
    DoublePaneReflective = 5
    DoublePaneClearLowEColdClimateHighSHGC = 6
    DoublePaneClearLowEHotClimateLowSHGC = 7
    DoublePaneClearHighestPerformanceLowEHighVisTransLowSHGC = 8
    TriplePaneClearLowEHotOrColdClimate = 9
    QuadPaneClearLowEHotOrColdClimate = 10
    NumWindowSkylightTypeConstruction = 11
    InvalidWindowSkylightTypeConstruction = -1


class ConceptualConstructionShadeType:
    BasicShade = 0
    NumShadeTypeConstruction = 1
    InvalidShadeTypeConstruction = -1


class ConceptualConstructionOpeningType:
    Air = 0
    NumOpeningTypeConstruction = 1
    InvalidOpeningTypeConstruction = -1


class ViewSystemsAnalysisReport(View):
    @property
    def SystemsAnalysisWorkflowFile(self) -> str: ...
    @property
    def WeatherFile(self) -> str: ...
    @property
    def SystemsAnalysisOutputFolder(self) -> str: ...
    @property
    def AnalysisDateAndTime(self) -> DateTime: ...
    def Create(document: Document, viewName: str) -> ViewSystemsAnalysisReport: ...
    def RequestSystemsAnalysis(self, options: SystemsAnalysisOptions) -> None: ...
    def GetLatestSystemsAnalysisReport(document: Document) -> ElementId: ...
    def IsAnalysisCompleted(self) -> bool: ...
    def GetReportContent(self) -> str: ...


class SystemsAnalysisOptions:
    def __init__(self): ...
    @property
    def WorkflowFile(self) -> str: ...
    @WorkflowFile.setter
    def WorkflowFile(self, fileName: str) -> None: ...
    @property
    def WeatherFile(self) -> str: ...
    @WeatherFile.setter
    def WeatherFile(self, fileName: str) -> None: ...
    @property
    def OutputFolder(self) -> str: ...
    @OutputFolder.setter
    def OutputFolder(self, pathName: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class MassGBXMLExportOptions:
    @overload
    def __init__(self, massZoneIds: List[ElementId]): ...
    @overload
    def __init__(self, massZoneIds: List[ElementId], massIds: List[ElementId]): ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetMassIds(self) -> List[ElementId]: ...
    def GetMassZoneIds(self) -> List[ElementId]: ...
    def Dispose(self) -> None: ...


class EnergyAnalysisDetailModelOptions:
    def __init__(self): ...
    @property
    def EnergyModelType(self) -> EnergyModelType: ...
    @EnergyModelType.setter
    def EnergyModelType(self, energyModelType: EnergyModelType) -> None: ...
    @property
    def Tier(self) -> EnergyAnalysisDetailModelTier: ...
    @Tier.setter
    def Tier(self, tier: EnergyAnalysisDetailModelTier) -> None: ...
    @property
    def IncludeShadingSurfaces(self) -> bool: ...
    @IncludeShadingSurfaces.setter
    def IncludeShadingSurfaces(self, includeShadingSurfaces: bool) -> None: ...
    @property
    def SimplifyCurtainSystems(self) -> bool: ...
    @SimplifyCurtainSystems.setter
    def SimplifyCurtainSystems(self, simplifyCurtainSystems: bool) -> None: ...
    @property
    def ExportMullions(self) -> bool: ...
    @ExportMullions.setter
    def ExportMullions(self, exportMullions: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class EnergyAnalysisDetailModel(Element):
    @property
    def Tier(self) -> EnergyAnalysisDetailModelTier: ...
    @property
    def IncludeShadingSurfaces(self) -> bool: ...
    @property
    def SimplifyCurtainSystems(self) -> bool: ...
    @property
    def ExportMullions(self) -> bool: ...
    @property
    def BuildingTypeId(self) -> ElementId: ...
    @BuildingTypeId.setter
    def BuildingTypeId(self, buildingTypeId: ElementId) -> None: ...
    @property
    def ExportCategory(self) -> ElementId: ...
    @ExportCategory.setter
    def ExportCategory(self, exportCategory: ElementId) -> None: ...
    def Create(document: Document, options: EnergyAnalysisDetailModelOptions) -> EnergyAnalysisDetailModel: ...
    def GetMainEnergyAnalysisDetailModel(document: Document) -> EnergyAnalysisDetailModel: ...
    def GetAnalyticalSpaces(self) -> List[EnergyAnalysisSpace]: ...
    def GetAnalyticalSurfaces(self) -> List[EnergyAnalysisSurface]: ...
    def GetAnalyticalOpenings(self) -> List[EnergyAnalysisOpening]: ...
    def GetAnalyticalShadingSurfaces(self) -> List[EnergyAnalysisSurface]: ...
    def TransformModel(self) -> None: ...


class EnergyAnalysisOpening(Element):
    @property
    def Width(self) -> float: ...
    @property
    def Height(self) -> float: ...
    @property
    def Type(self) -> gbXMLOpeningType: ...
    @property
    def OpeningName(self) -> str: ...
    @property
    def CADObjectUniqueId(self) -> str: ...
    @property
    def CADLinkUniqueId(self) -> str: ...
    @property
    def OpeningType(self) -> EnergyAnalysisOpeningType: ...
    @property
    def Corner(self) -> XYZ: ...
    @property
    def OriginatingElementDescription(self) -> str: ...
    @property
    def OpeningId(self) -> str: ...
    def GetAnalyticalSurface(self) -> EnergyAnalysisSurface: ...
    def GetPolyloop(self) -> Polyloop: ...


class EnergyAnalysisSpace(Element):
    @property
    def Area(self) -> float: ...
    @property
    def AnalyticalVolume(self) -> float: ...
    @property
    def InnerVolume(self) -> float: ...
    @property
    def SpaceName(self) -> str: ...
    @property
    def Description(self) -> str: ...
    @property
    def ComposedName(self) -> str: ...
    @property
    def CADObjectUniqueId(self) -> str: ...
    def GetAnalyticalSurfaces(self) -> List[EnergyAnalysisSurface]: ...
    def GetClosedShell(self) -> List[Polyloop]: ...
    def GetBoundary(self) -> List[Polyloop]: ...


class EnergyAnalysisSurface(Element):
    @property
    def Width(self) -> float: ...
    @property
    def Height(self) -> float: ...
    @property
    def Azimuth(self) -> float: ...
    @property
    def Tilt(self) -> float: ...
    @property
    def Type(self) -> gbXMLSurfaceType: ...
    @property
    def SurfaceName(self) -> str: ...
    @property
    def CADObjectUniqueId(self) -> str: ...
    @property
    def CADLinkUniqueId(self) -> str: ...
    @property
    def OriginatingElementDescription(self) -> str: ...
    @property
    def SurfaceType(self) -> EnergyAnalysisSurfaceType: ...
    @property
    def Normal(self) -> XYZ: ...
    @property
    def Corner(self) -> XYZ: ...
    @property
    def SurfaceId(self) -> str: ...
    def GetAnalyticalSpace(self) -> EnergyAnalysisSpace: ...
    def GetAdjacentAnalyticalSpace(self) -> EnergyAnalysisSpace: ...
    def GetAnalyticalOpenings(self) -> List[EnergyAnalysisOpening]: ...
    def GetPolyloop(self) -> Polyloop: ...


class Polyloop:
    @property
    def Centroid(self) -> XYZ: ...
    @property
    def Direction(self) -> XYZ: ...
    @property
    def IsValidObject(self) -> bool: ...
    def ComputeArea(self) -> float: ...
    def GetPoints(self) -> List[XYZ]: ...
    def Dispose(self) -> None: ...


class EnergyDataSettings(Element):
    @property
    def SliverSpaceTolerance(self) -> float: ...
    @SliverSpaceTolerance.setter
    def SliverSpaceTolerance(self, sliverSpaceTolerance: float) -> None: ...
    @property
    def PercentageGlazing(self) -> float: ...
    @PercentageGlazing.setter
    def PercentageGlazing(self, percentageGlazing: float) -> None: ...
    @property
    def SillHeight(self) -> float: ...
    @SillHeight.setter
    def SillHeight(self, sillHeight: float) -> None: ...
    @property
    def ShadeDepth(self) -> float: ...
    @ShadeDepth.setter
    def ShadeDepth(self, shadeDepth: float) -> None: ...
    @property
    def PercentageSkylights(self) -> float: ...
    @PercentageSkylights.setter
    def PercentageSkylights(self, percentageSkylights: float) -> None: ...
    @property
    def SkylightWidth(self) -> float: ...
    @SkylightWidth.setter
    def SkylightWidth(self, skylightWidth: float) -> None: ...
    @property
    def OutsideAirPerPerson(self) -> float: ...
    @OutsideAirPerPerson.setter
    def OutsideAirPerPerson(self, outsideAirPerPerson: float) -> None: ...
    @property
    def OutsideAirPerArea(self) -> float: ...
    @OutsideAirPerArea.setter
    def OutsideAirPerArea(self, outsideAirPerArea: float) -> None: ...
    @property
    def OutsideAirChangesRatePerHour(self) -> float: ...
    @OutsideAirChangesRatePerHour.setter
    def OutsideAirChangesRatePerHour(self, outsideAirChangesRatePerHour: float) -> None: ...
    @property
    def ExportComplexity(self) -> gbXMLExportComplexity: ...
    @ExportComplexity.setter
    def ExportComplexity(self, exportComplexity: gbXMLExportComplexity) -> None: ...
    @property
    def BuildingConstructionClass(self) -> HVACLoadConstructionClass: ...
    @BuildingConstructionClass.setter
    def BuildingConstructionClass(self, buildingConstructionClass: HVACLoadConstructionClass) -> None: ...
    @property
    def ProjectReportType(self) -> HVACLoadLoadsReportType: ...
    @ProjectReportType.setter
    def ProjectReportType(self, projectReportType: HVACLoadLoadsReportType) -> None: ...
    @property
    def BuildingOperatingSchedule(self) -> gbXMLBuildingOperatingSchedule: ...
    @BuildingOperatingSchedule.setter
    def BuildingOperatingSchedule(self, buildingOperatingSchedule: gbXMLBuildingOperatingSchedule) -> None: ...
    @property
    def BuildingHVACSystem(self) -> gbXMLBuildingHVACSystem: ...
    @BuildingHVACSystem.setter
    def BuildingHVACSystem(self, buildingHVACSystem: gbXMLBuildingHVACSystem) -> None: ...
    @property
    def ExportCategory(self) -> ElementId: ...
    @ExportCategory.setter
    def ExportCategory(self, exportCategory: ElementId) -> None: ...
    @property
    def GroundPlane(self) -> ElementId: ...
    @GroundPlane.setter
    def GroundPlane(self, groundPlane: ElementId) -> None: ...
    @property
    def ProjectPhase(self) -> ElementId: ...
    @ProjectPhase.setter
    def ProjectPhase(self, projectPhase: ElementId) -> None: ...
    @property
    def AnalysisType(self) -> AnalysisMode: ...
    @AnalysisType.setter
    def AnalysisType(self, analysisType: AnalysisMode) -> None: ...
    @property
    def BuildingTypeId(self) -> ElementId: ...
    @BuildingTypeId.setter
    def BuildingTypeId(self, buildingTypeId: ElementId) -> None: ...
    @property
    def ServiceType(self) -> gbXMLServiceType: ...
    @ServiceType.setter
    def ServiceType(self, serviceType: gbXMLServiceType) -> None: ...
    @property
    def ExportDefaults(self) -> bool: ...
    @ExportDefaults.setter
    def ExportDefaults(self, exportDefaults: bool) -> None: ...
    @property
    def UseHeatingCredits(self) -> bool: ...
    @UseHeatingCredits.setter
    def UseHeatingCredits(self, useHeatingCredits: bool) -> None: ...
    @property
    def CreateAnalyticalModel(self) -> bool: ...
    @property
    def IsGlazingShaded(self) -> bool: ...
    @IsGlazingShaded.setter
    def IsGlazingShaded(self, isGlazingShaded: bool) -> None: ...
    @property
    def UseOutsideAirPerPerson(self) -> bool: ...
    @UseOutsideAirPerPerson.setter
    def UseOutsideAirPerPerson(self, useOutsideAirPerPerson: bool) -> None: ...
    @property
    def UseOutsideAirPerArea(self) -> bool: ...
    @UseOutsideAirPerArea.setter
    def UseOutsideAirPerArea(self, useOutsideAirPerArea: bool) -> None: ...
    @property
    def UseAirChangesPerHour(self) -> bool: ...
    @UseAirChangesPerHour.setter
    def UseAirChangesPerHour(self, useAirChangesPerHour: bool) -> None: ...
    @property
    def IncludeThermalProperties(self) -> bool: ...
    @IncludeThermalProperties.setter
    def IncludeThermalProperties(self, includeThermalProperties: bool) -> None: ...
    @property
    def BuildingEnvelopeDeterminationMethod(self) -> gbXMLExportBuildingEnvelope: ...
    @BuildingEnvelopeDeterminationMethod.setter
    def BuildingEnvelopeDeterminationMethod(self, buildingEnvelopeDeterminationMethod: gbXMLExportBuildingEnvelope) -> None: ...
    @property
    def AnalyticalGridCellSize(self) -> float: ...
    @AnalyticalGridCellSize.setter
    def AnalyticalGridCellSize(self, analyticalGridCellSize: float) -> None: ...
    @property
    def IsExportShadingSurfacesEnabled(self) -> bool: ...
    @property
    def IsExportSimplifiedCurtainSystemsEnabled(self) -> bool: ...
    @property
    def IsExportMullionsEnabled(self) -> bool: ...
    @property
    def CoreOffset(self) -> float: ...
    @CoreOffset.setter
    def CoreOffset(self, coreOffset: float) -> None: ...
    @property
    def BuildingType(self) -> gbXMLBuildingType: ...
    @BuildingType.setter
    def BuildingType(self, buildingType: gbXMLBuildingType) -> None: ...
    @property
    def EnergyModel(self) -> bool: ...
    @EnergyModel.setter
    def EnergyModel(self, energyModel: bool) -> None: ...
    @property
    def DividePerimeter(self) -> bool: ...
    @DividePerimeter.setter
    def DividePerimeter(self, dividePerimeter: bool) -> None: ...
    def GetFromDocument(cda: Document) -> EnergyDataSettings: ...
    def IsDocumentUsingEnergyDataAnalyticalModel(ccda: Document) -> bool: ...
    def CheckRangeOfSliverSpaceTolerance(silverSpaceTolerance: float) -> bool: ...
    def CheckRangeOfPercentageGlazing(percentageGlazing: float) -> bool: ...
    def CheckRangeOfSillHeight(sillHeight: float) -> bool: ...
    def CheckRangeOfShadeDepth(shadeDepth: float) -> bool: ...
    def CheckRangeOfPercentageSkylights(percentageSkylights: float) -> bool: ...
    def CheckRangeOfSkylightWidth(skylightWidth: float) -> bool: ...
    def CheckExportCategory(exportCategoryId: ElementId) -> bool: ...
    def CheckConstructionSetElement(self, constructionSetElementId: ElementId) -> bool: ...
    @overload
    def CheckGroundPlane(ccda: Document, groundPlaneId: ElementId) -> bool: ...
    @overload
    def CheckGroundPlane(self, groundPlaneId: ElementId) -> bool: ...
    def CheckProjectPhase(self, projectPhaseId: ElementId) -> bool: ...
    def CheckExportComplexity(exportComplexity: gbXMLExportComplexity) -> bool: ...
    def CheckBuildingConstructionClass(buildingConstructionClass: HVACLoadConstructionClass) -> bool: ...
    def CheckProjectReportType(projectReportType: HVACLoadLoadsReportType) -> bool: ...
    def CheckBuildingOperatingSchedule(buildingOperatingSchedule: gbXMLBuildingOperatingSchedule) -> bool: ...
    def CheckBuildingHVACSystem(buildingHVACSystem: gbXMLBuildingHVACSystem) -> bool: ...
    def CheckBuildingType(buildingType: gbXMLBuildingType) -> bool: ...
    def CheckServiceType(serviceType: gbXMLServiceType) -> bool: ...
    def CheckBuildingEnvelope(determinationMethod: gbXMLExportBuildingEnvelope) -> bool: ...
    def CheckAnalysisType(analysisType: AnalysisMode) -> bool: ...
    def EnableConceptualEnergyAnalyticalModel() -> bool: ...
    def GetBuildingConstructionSetElementId(ccda: Document) -> ElementId: ...
    def SetCreateAnalyticalModel(self, createAnalyticalModel: bool) -> None: ...


class AnalysisMode:
    BuildingElements = 0
    ConceptualMasses = 1
    ConceptualMassesAndBuildingElements = 2


class EnergyAnalysisDetailModelTier:
    NotComputed = 0
    FirstLevelBoundaries = 1
    SecondLevelBoundaries = 2
    Final = 3


class EnergyModelType:
    SpatialElement = 0
    BuildingElement = 1


class EnergyAnalysisOpeningType:
    Door = 0
    Window = 1
    Skylight = 2
    Air = 3


class EnergyAnalysisSurfaceType:
    Roof = 0
    ExteriorWall = 1
    InteriorWall = 2
    Ceiling = 3
    InteriorFloor = 4
    ExteriorFloor = 5
    Shading = 6
    Air = 7
    Underground = 8


class FieldDomainPoints:
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class FieldDomainPointsByParameter(FieldDomainPoints):
    def __init__(self, points: List[float]): ...


class FieldDomainPointsByUV(FieldDomainPoints):
    @overload
    def __init__(self, points: List[UV], uCoordinates: ICollection, vCoordinates: ICollection): ...
    @overload
    def __init__(self, points: List[UV]): ...
    def SetGridCoordinates(self, uCoordinates: ICollection, vCoordinates: ICollection) -> None: ...


class FieldDomainPointsByXYZ(FieldDomainPoints):
    def __init__(self, points: List[XYZ]): ...


class ValueAtPoint(ValueAtPointBase):
    @overload
    def __init__(self, otherObject: ValueAtPoint): ...
    @overload
    def __init__(self, values: List[float]): ...


class VectorAtPoint(ValueAtPointBase):
    @overload
    def __init__(self, otherObject: VectorAtPoint): ...
    @overload
    def __init__(self, vectors: List[XYZ]): ...


class FieldValues:
    @overload
    def __init__(self, otherObject: FieldValues): ...
    @overload
    def __init__(self, vectorAtPoint: List[VectorAtPoint]): ...
    @overload
    def __init__(self, valueAtPoint: List[ValueAtPoint], unitDirection: XYZ): ...
    @overload
    def __init__(self, valueAtPoint: List[ValueAtPoint]): ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class GenericZone(Element):
    @property
    def LevelOffset(self) -> float: ...
    @LevelOffset.setter
    def LevelOffset(self, offset: float) -> None: ...
    def Create(doc: Document, name: str, domainData: GenericZoneDomainData, levelId: ElementId, curveLoops: List[CurveLoop]) -> GenericZone: ...
    def GetDomainData(self) -> GenericZoneDomainData: ...
    def GetBoundaries(self) -> List[CurveLoop]: ...


class GenericZoneDomainData:
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class PathOfTravelCalculationServerIds:
    @property
    def DefaultPathOfTravelCalculationGUID() -> Guid: ...


class PathOfTravelCalculationRequestType:
    CalculateForCorrespondingStartEndPairs = 0
    CalculateForAllPossibleStartEndPairs = 1
    CalculateFarthestPointsToMultipleDestinations = 2
    GetRevealObstaclesModeInView = 3
    SetRevealObstaclesModeInView = 4
    LockCache = 5
    UnlockCache = 6
    CalculateForPathsWithWaypoints = 7
    GetDistanceMapModeInView = 8
    SetDistanceMapModeInView = 9
    CalculateShortestPathsToMultipleDestinations = 10


class PathOfTravelCalculationStatus:
    Success = 0
    NoPathOfTravel = 1
    AreaTooLarge = 2
    SplitView = 3
    ResultAffectedByCrop = 4
    StartAndEndPointsTooClose = 5
    PointOutsideActiveCrop = 6
    TooMuchGeometry = 7
    RevealObstaclesModeFailureDataExist = 8
    RevealObstaclesModeFailureWireframe = 9
    TemporaryModeFailureDataExist = 10
    TemporaryModeFailureWireframe = 11


class MassEnergyAnalyticalModel(Element):
    @property
    def MassZoneCoreOffset(self) -> float: ...
    @MassZoneCoreOffset.setter
    def MassZoneCoreOffset(self, massZoneCoreOffset: float) -> None: ...
    @property
    def MassId(self) -> ElementId: ...
    def GetMassZoneIds(self) -> ICollection: ...
    def GetCoincidentEnergyAnalyticalModelFaceReference(document: Document, referenceToFace: Reference) -> Reference: ...
    def GetCoincidentMassZoneFaceReferences(document: Document, referenceToFace: Reference) -> List[Reference]: ...
    def GetMassSurfaceDataIdForReference(self, reference: Reference) -> ElementId: ...
    def GetMassEnergyAnalyticalModelIdForMassInstance(document: Document, massInstanceId: ElementId) -> ElementId: ...
    def GetValidSurfaceCategoryIdsForReference(self, reference: Reference) -> Tuple[List[ElementId], ElementId]: ...
    def GetJoinedMassEnergyAnalyticalModelElementIds(self) -> ICollection: ...
    def GetReferencesToAllFaces(self) -> List[Reference]: ...
    def GetReferencesToAllShadingFaces(self) -> List[Reference]: ...


class MassSurfaceData(Element):
    @property
    def Area(self) -> float: ...
    @property
    def PercentageGlazing(self) -> float: ...
    @PercentageGlazing.setter
    def PercentageGlazing(self, percentageGlazing: float) -> None: ...
    @property
    def ShadeDepth(self) -> float: ...
    @ShadeDepth.setter
    def ShadeDepth(self, shadeDepth: float) -> None: ...
    @property
    def SillHeight(self) -> float: ...
    @SillHeight.setter
    def SillHeight(self, sillHeight: float) -> None: ...
    @property
    def PercentageSkylights(self) -> float: ...
    @PercentageSkylights.setter
    def PercentageSkylights(self, percentageSkylights: float) -> None: ...
    @property
    def SkylightWidth(self) -> float: ...
    @SkylightWidth.setter
    def SkylightWidth(self, skylightWidth: float) -> None: ...
    @property
    def SurfaceDataSource(self) -> MassSurfaceDataSource: ...
    @SurfaceDataSource.setter
    def SurfaceDataSource(self, surfaceDataSource: MassSurfaceDataSource) -> None: ...
    @property
    def ConceptualConstructionId(self) -> ElementId: ...
    @ConceptualConstructionId.setter
    def ConceptualConstructionId(self, conceptualConstructionId: ElementId) -> None: ...
    @property
    def MassLevelDataId(self) -> ElementId: ...
    @property
    def MaterialId(self) -> ElementId: ...
    @MaterialId.setter
    def MaterialId(self, materialId: ElementId) -> None: ...
    @property
    def MaterialType(self) -> MassSurfaceDataMaterialType: ...
    @MaterialType.setter
    def MaterialType(self, materialType: MassSurfaceDataMaterialType) -> None: ...
    @property
    def IsConceptualConstructionByEnergyData(self) -> bool: ...
    @IsConceptualConstructionByEnergyData.setter
    def IsConceptualConstructionByEnergyData(self, IsConceptualConstructionByEnergyData: bool) -> None: ...
    @property
    def IsGlazingShaded(self) -> bool: ...
    @IsGlazingShaded.setter
    def IsGlazingShaded(self, isGlazingShaded: bool) -> None: ...
    @property
    def IsUnderground(self) -> bool: ...
    @IsUnderground.setter
    def IsUnderground(self, isUnderground: bool) -> None: ...
    @property
    def IsSlab(self) -> bool: ...
    @property
    def CategoryIdForConceptualSurfaceType(self) -> ElementId: ...
    @property
    def ReferenceElementId(self) -> ElementId: ...
    def GetFaceReferences(self) -> List[Reference]: ...


class MassLevelData(Element):
    @property
    def StrUsage(self) -> str: ...
    @StrUsage.setter
    def StrUsage(self, strUsage: str) -> None: ...
    @property
    def NVolume(self) -> float: ...
    @property
    def NExteriorSurfaceArea(self) -> float: ...
    @property
    def NLevelFafArea(self) -> float: ...
    @property
    def NLevelPerimeter(self) -> float: ...
    @property
    def MaterialType(self) -> MassSurfaceDataMaterialType: ...
    @MaterialType.setter
    def MaterialType(self, materialType: MassSurfaceDataMaterialType) -> None: ...
    @property
    def OwningMassId(self) -> ElementId: ...
    @property
    def MaterialId(self) -> ElementId: ...
    @MaterialId.setter
    def MaterialId(self, materialId: ElementId) -> None: ...
    @property
    def ConceptualConstructionId(self) -> ElementId: ...
    @ConceptualConstructionId.setter
    def ConceptualConstructionId(self, conceptualConstructionId: ElementId) -> None: ...
    @property
    def ConceptualConstructionIsByEnergyData(self) -> bool: ...
    @ConceptualConstructionIsByEnergyData.setter
    def ConceptualConstructionIsByEnergyData(self, conceptualConstructionIsByEnergyData: bool) -> None: ...
    def IsEmpty(self) -> bool: ...
    def IsMassFamilyInstance(document: Document, id: ElementId) -> bool: ...
    def IsValidConceptualConstructionTypeElement(self, id: ElementId) -> bool: ...


class MassZone(Element):
    @property
    def Volume(self) -> float: ...
    @property
    def FloorArea(self) -> float: ...
    @property
    def LowerLevelId(self) -> ElementId: ...
    @property
    def UpperLevelId(self) -> ElementId: ...
    @property
    def MaterialId(self) -> ElementId: ...
    @MaterialId.setter
    def MaterialId(self, materialId: ElementId) -> None: ...
    @property
    def MaterialType(self) -> MassZoneMaterialType: ...
    @MaterialType.setter
    def MaterialType(self, materialType: MassZoneMaterialType) -> None: ...
    @property
    def IsZoneOccupiable(self) -> bool: ...
    @property
    def MassEnergyAnalyticalModelId(self) -> ElementId: ...
    @property
    def CutByLowerLevel(self) -> MassZoneLevelCutState: ...
    @property
    def CutByUpperLevel(self) -> MassZoneLevelCutState: ...
    @property
    def ConditionType(self) -> gbXMLConditionType: ...
    @ConditionType.setter
    def ConditionType(self, conditionType: gbXMLConditionType) -> None: ...
    @property
    def SpaceType(self) -> gbXMLSpaceType: ...
    @SpaceType.setter
    def SpaceType(self, spaceType: gbXMLSpaceType) -> None: ...
    @property
    def SpaceTypeId(self) -> ElementId: ...
    @SpaceTypeId.setter
    def SpaceTypeId(self, spaceType: ElementId) -> None: ...
    def IsEmpty(self) -> bool: ...
    def GetEquivalentReferenceFromMassOrLevel(self, referenceToZoneFace: Reference) -> Reference: ...
    def GetCoincidentReferenceFromAdjacentZone(self, referenceToZoneFace: Reference) -> Reference: ...
    def GetReferencesToEnergyAnalysisFaces(self) -> List[Reference]: ...
    def GetMassDataElementIdForZoneFaceReference(self, referenceOfZone: Reference) -> ElementId: ...


class MassSurfaceDataSource:
    EnergyData = 0
    Surface = 1
    Invalid = -1


class MassSurfaceDataMaterialType:
    NormalMaterial = 0
    MaterialByConstruction = -2


class MassZoneMaterialType:
    NormalMaterial = 0
    MaterialBySurfaceType = -2


class MassZoneLevelCutState:
    NotCut = 0
    Cut = 1
    NotCutButCoincident = 2


class PathOfTravel(Element):
    @property
    def PathMidpoint(self) -> XYZ: ...
    @property
    def PathStart(self) -> XYZ: ...
    @PathStart.setter
    def PathStart(self, pathStart: XYZ) -> None: ...
    @property
    def PathEnd(self) -> XYZ: ...
    @PathEnd.setter
    def PathEnd(self, pathEnd: XYZ) -> None: ...
    @property
    def LineStyle(self) -> ElementId: ...
    @LineStyle.setter
    def LineStyle(self, lineStyle: ElementId) -> None: ...
    @overload
    def Create(DBView: View, pathStart: XYZ, pathEnd: XYZ) -> PathOfTravel: ...
    @overload
    def Create(DBView: View, pathStart: XYZ, pathEnd: XYZ) -> Tuple[PathOfTravel, PathOfTravelCalculationStatus]: ...
    @overload
    def CreateMultiple(DBView: View, pathStarts: List[XYZ], pathEnds: List[XYZ]) -> Tuple[List[PathOfTravel], List[PathOfTravelCalculationStatus]]: ...
    @overload
    def CreateMultiple(DBView: View, pathStarts: List[XYZ], pathEnds: List[XYZ]) -> List[PathOfTravel]: ...
    @overload
    def CreateMapped(DBView: View, pathStarts: List[XYZ], pathEnds: List[XYZ]) -> List[PathOfTravel]: ...
    @overload
    def CreateMapped(DBView: View, pathStarts: List[XYZ], pathEnds: List[XYZ]) -> Tuple[List[PathOfTravel], List[PathOfTravelCalculationStatus]]: ...
    def FindStartsOfLongestPathsFromRooms(DBView: View, destinationPoints: List[XYZ]) -> List[XYZ]: ...
    def FindEndsOfShortestPaths(DBView: View, destinationPoints: List[XYZ], startPoints: List[XYZ]) -> List[XYZ]: ...
    def FindShortestPaths(DBView: View, destinationPoints: List[XYZ], startPoints: List[XYZ]) -> List[XYZ]: ...
    def Update(self) -> PathOfTravelCalculationStatus: ...
    @overload
    def UpdateMultiple(adoc: Document, elementsToUpdate: List[ElementId]) -> Tuple[int, List[PathOfTravelCalculationStatus]]: ...
    @overload
    def UpdateMultiple(adoc: Document, elementsToUpdate: List[ElementId]) -> int: ...
    def GetCurves(self) -> List[Curve]: ...
    def GetWaypoints(self) -> List[XYZ]: ...
    def InsertWaypoint(self, waypoint: XYZ, index: int) -> None: ...
    def SetWaypoint(self, waypoint: XYZ, index: int) -> None: ...
    def RemoveWaypoint(self, index: int) -> None: ...
    def IsInRevealObstaclesMode(DBView: View) -> bool: ...
    def SetRevealObstaclesMode(DBView: View, newState: bool) -> PathOfTravelCalculationStatus: ...


class RouteAnalysisSettings(Element):
    @property
    def EnableIgnoredCategoryIds(self) -> bool: ...
    @EnableIgnoredCategoryIds.setter
    def EnableIgnoredCategoryIds(self, enableIgnoredCategoryIds: bool) -> None: ...
    @property
    def IgnoreImports(self) -> bool: ...
    @IgnoreImports.setter
    def IgnoreImports(self, ignoreImports: bool) -> None: ...
    @property
    def AnalysisZoneBottomOffset(self) -> float: ...
    @AnalysisZoneBottomOffset.setter
    def AnalysisZoneBottomOffset(self, bottomOffset: float) -> None: ...
    @property
    def AnalysisZoneTopOffset(self) -> float: ...
    @AnalysisZoneTopOffset.setter
    def AnalysisZoneTopOffset(self, topOffset: float) -> None: ...
    @property
    def MinimumLength(self) -> float: ...
    def GetRouteAnalysisSettings(cda: Document) -> RouteAnalysisSettings: ...
    def GetIgnoredCategoryIds(self) -> ICollection: ...
    def GetExcludedCategoryIds(self) -> ICollection: ...
    def SetIgnoredCategoryIds(self, categoryIds: ICollection) -> None: ...
    def IsLargeGeometryAllowed(self) -> bool: ...


class AllowLargeGeometry:
    DisAllow = 0
    Allow = 1
    Prompt = 2


class SpatialFieldManager(Element):
    @property
    def AllowInteractiveSettings(self) -> bool: ...
    @AllowInteractiveSettings.setter
    def AllowInteractiveSettings(self, allowInteractiveSettings: bool) -> None: ...
    @property
    def NumberOfMeasurements(self) -> int: ...
    @property
    def LegendPosition(self) -> XYZ: ...
    @LegendPosition.setter
    def LegendPosition(self, newLegendPosition: XYZ) -> None: ...
    @property
    def CurrentMeasurement(self) -> int: ...
    @CurrentMeasurement.setter
    def CurrentMeasurement(self, measurement: int) -> None: ...
    @property
    def UseRangeForAllMeasurements(self) -> bool: ...
    @UseRangeForAllMeasurements.setter
    def UseRangeForAllMeasurements(self, useRangeForAllMeasurements: bool) -> None: ...
    @property
    def ResultsVisibleInView(self) -> bool: ...
    @ResultsVisibleInView.setter
    def ResultsVisibleInView(self, bResultsVisibleInView: bool) -> None: ...
    @property
    def LegendTextTypeId(self) -> ElementId: ...
    @LegendTextTypeId.setter
    def LegendTextTypeId(self, legendTextTypeId: ElementId) -> None: ...
    @property
    def LegendShowConfigurationName(self) -> bool: ...
    @LegendShowConfigurationName.setter
    def LegendShowConfigurationName(self, legendShowConfigurationName: bool) -> None: ...
    @property
    def LegendShowDescription(self) -> bool: ...
    @LegendShowDescription.setter
    def LegendShowDescription(self, legendShowDescription: bool) -> None: ...
    def CreateSpatialFieldManager(view: View, numberOfMeasurements: int) -> SpatialFieldManager: ...
    def GetSpatialFieldManager(view: View) -> SpatialFieldManager: ...
    @overload
    def AddSpatialFieldPrimitive(self, curve: Curve, trf: Transform) -> int: ...
    @overload
    def AddSpatialFieldPrimitive(self, face: Face, trf: Transform) -> int: ...
    @overload
    def AddSpatialFieldPrimitive(self, reference: Reference, hidingMode: SpatialFieldPrimitiveHideMode) -> int: ...
    @overload
    def AddSpatialFieldPrimitive(self, reference: Reference) -> int: ...
    @overload
    def AddSpatialFieldPrimitive(self) -> int: ...
    def RemoveSpatialFieldPrimitive(self, idx: int) -> None: ...
    def UpdateSpatialFieldPrimitive(self, idx: int, fieldDomainPoints: FieldDomainPoints, fieldValues: FieldValues, resultIndex: int) -> None: ...
    def Clear(self) -> None: ...
    def GetLegend(self) -> AnalysisDisplayLegend: ...
    def GetMinimum(self, resultIndex: int, rawValue: bool) -> float: ...
    def GetMaximum(self, resultIndex: int, rawValue: bool) -> float: ...
    def SetMeasurementNames(self, measurementNames: List[str]) -> None: ...
    def SetMeasurementDescriptions(self, measurementDescriptions: List[str]) -> None: ...
    def IsResultSchemaNameUnique(self, name: str, resultIndexToSkip: int) -> bool: ...
    def RegisterResult(self, resultSchema: AnalysisResultSchema) -> int: ...
    def GetResultSchema(self, idx: int) -> AnalysisResultSchema: ...
    def SetResultSchema(self, idx: int, resultSchema: AnalysisResultSchema) -> None: ...
    def GetRegisteredResults(self) -> List[int]: ...
    def IsTextTypeIdValid(textTypeId: ElementId, doc: Document) -> bool: ...


class SpatialFieldPrimitiveHideMode:
    Default = 0
    HideNone = 1
    HideOnlyReference = 2
    HideWholeElement = 3



class ListSortDescription(object):
 """
 Provides a description of the sort operation applied to a data source.

 

 ListSortDescription(property: PropertyDescriptor,direction: ListSortDirection)
 """
 @staticmethod
 def __new__(self,property,direction):
  """ __new__(cls: type,property: PropertyDescriptor,direction: ListSortDirection) """
  pass
 PropertyDescriptor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the abstract description of a class property associated with this System.ComponentModel.ListSortDescription



Get: PropertyDescriptor(self: ListSortDescription) -> PropertyDescriptor



Set: PropertyDescriptor(self: ListSortDescription)=value

"""

 SortDirection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the direction of the sort operation associated with this System.ComponentModel.ListSortDescription.



Get: SortDirection(self: ListSortDescription) -> ListSortDirection



Set: SortDirection(self: ListSortDescription)=value

"""





class ValidationResult(object):
 """
 Represents the result returned by the System.Windows.Controls.ValidationRule.System.Windows.Controls.ValidationRule.Validate(System.Object,System.Globalization.CultureInfo) method that indicates whether the checked value passed the System.Windows.Controls.ValidationRule.

 

 ValidationResult(isValid: bool,errorContent: object)
 """
 def Equals(self,obj):
  """
  Equals(self: ValidationResult,obj: object) -> bool

  

   Compares the specified instance and the current instance of 

    System.Windows.Controls.ValidationResult for value equality.

  

  

   obj: The System.Windows.Controls.ValidationResult instance to compare.

   Returns: true if obj and this instance of System.Windows.Controls.ValidationResult.have the same values.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: ValidationResult) -> int

  

   Returns the hash code for this System.Windows.Controls.ValidationResult.

   Returns: The hash code for this System.Windows.Controls.ValidationResult.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,isValid,errorContent):
  """ __new__(cls: type,isValid: bool,errorContent: object) """
  pass
 def __ne__(self,*args):
  pass
 ErrorContent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an object that provides additional information about the invalidity.



Get: ErrorContent(self: ValidationResult) -> object



"""

 IsValid=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the value checked against the System.Windows.Controls.ValidationRule is valid.



Get: IsValid(self: ValidationResult) -> bool



"""


 ValidResult=None




class LocalizableAttribute(Attribute,_Attribute):
 """
 Specifies whether a property should be localized. This class cannot be inherited.

 

 LocalizableAttribute(isLocalizable: bool)
 """
 def Equals(self,obj):
  """
  Equals(self: LocalizableAttribute,obj: object) -> bool

  

   Returns whether the value of the given object is equal to the current 

    System.ComponentModel.LocalizableAttribute.

  

  

   obj: The object to test the value equality of.

   Returns: true if the value of the given object is equal to that of the current; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: LocalizableAttribute) -> int

  

   Returns the hash code for this instance.

   Returns: A hash code for the current System.ComponentModel.LocalizableAttribute.
  """
  pass
 def IsDefaultAttribute(self):
  """
  IsDefaultAttribute(self: LocalizableAttribute) -> bool

  

   Determines if this attribute is the default.

   Returns: true if the attribute is the default value for this attribute class; otherwise,false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,isLocalizable):
  """ __new__(cls: type,isLocalizable: bool) """
  pass
 def __ne__(self,*args):
  pass
 IsLocalizable=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether a property should be localized.



Get: IsLocalizable(self: LocalizableAttribute) -> bool



"""


 Default=None
 No=None
 Yes=None




class ToolStripItemEventArgs(EventArgs):
 """
 Provides data for System.Windows.Forms.ToolStripItem events.

 

 ToolStripItemEventArgs(item: ToolStripItem)
 """
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 @staticmethod
 def __new__(self,item):
  """ __new__(cls: type,item: ToolStripItem) """
  pass
 Item=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Windows.Forms.ToolStripItem for which to handle events.



Get: Item(self: ToolStripItemEventArgs) -> ToolStripItem



"""





class FileWebResponse(WebResponse,ISerializable,IDisposable,ICloseEx):
 """ Provides a file system implementation of the System.Net.WebResponse class. """
 def Close(self):
  """
  Close(self: FileWebResponse)

   Closes the response stream.
  """
  pass
 def Dispose(self):
  """ Dispose(self: WebResponse,disposing: bool) """
  pass
 def GetObjectData(self,*args):
  """
  GetObjectData(self: FileWebResponse,serializationInfo: SerializationInfo,streamingContext: StreamingContext)

   Populates a System.Runtime.Serialization.SerializationInfo with the data needed to serialize the 

    target object.

  

  

   serializationInfo: The System.Runtime.Serialization.SerializationInfo to populate with data.

   streamingContext: A System.Runtime.Serialization.StreamingContext that specifies the destination for this 

    serialization.
  """
  pass
 def GetResponseStream(self):
  """
  GetResponseStream(self: FileWebResponse) -> Stream

  

   Returns the data stream from the file system resource.

   Returns: A System.IO.Stream for reading data from the file system resource.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """ __new__(cls: type,serializationInfo: SerializationInfo,streamingContext: StreamingContext) """
  pass
 def __reduce_ex__(self,*args):
  pass
 ContentLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the length of the content in the file system resource.



Get: ContentLength(self: FileWebResponse) -> Int64



"""

 ContentType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the content type of the file system resource.



Get: ContentType(self: FileWebResponse) -> str



"""

 Headers=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection of header name/value pairs associated with the response.



Get: Headers(self: FileWebResponse) -> WebHeaderCollection



"""

 ResponseUri=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the URI of the file system resource that provided the response.



Get: ResponseUri(self: FileWebResponse) -> Uri



"""

 SupportsHeaders=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: SupportsHeaders(self: FileWebResponse) -> bool



"""





class _Assembly:
 """ Exposes the public members of the System.Reflection.Assembly class to unmanaged code. """
 def CreateInstance(self,typeName,ignoreCase=None,bindingAttr=None,binder=None,args=None,culture=None,activationAttributes=None):
  """
  CreateInstance(self: _Assembly,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object]) -> object

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.CreateInstance(System.String,System.Boolean,System.Reflection.BindingF

    lags,System.Reflection.Binder,System.Object[],System.Globalization.CultureInfo,System.Object[]) 

    method.

  

  

   typeName: The System.Type.FullName of the type to locate.

   ignoreCase: true to ignore the case of the type name; otherwise,false.

   bindingAttr: A bitmask that affects how the search is conducted. The value is a combination of bit flags from 

    System.Reflection.BindingFlags.

  

   binder: An object that enables the binding,coercion of argument types,invocation of members,and 

    retrieval of MemberInfo objects via reflection. If binder is null,the default binder is used.

  

   args: An array of type Object containing the arguments to be passed to the constructor. This array of 

    arguments must match in number,order,and type the parameters of the constructor to be invoked. 

    If the default constructor is desired,args must be an empty array or null.

  

   culture: An instance of CultureInfo used to govern the coercion of types. If this is null,the 

    CultureInfo for the current thread is used. (This is necessary to convert a String that 

    represents 1000 to a Double value,for example,since 1000 is represented differently by 

    different cultures.)

  

   activationAttributes: An array of type Object containing one or more activation attributes that can participate in the 

    activation. An example of an activation attribute is: 

    URLAttribute(http://hostname/appname/objectURI)

  

   Returns: An instance of Object representing the type and matching the specified criteria,or null if 

    typeName is not found.

  

  CreateInstance(self: _Assembly,typeName: str,ignoreCase: bool) -> object

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.CreateInstance(System.String,System.Boolean) method.

  

  

   typeName: The System.Type.FullName of the type to locate.

   ignoreCase: true to ignore the case of the type name; otherwise,false.

   Returns: An instance of System.Object representing the type,with culture,arguments,binder,and 

    activation attributes set to null,and System.Reflection.BindingFlags set to Public or Instance,

    or null if typeName is not found.

  

  CreateInstance(self: _Assembly,typeName: str) -> object

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.CreateInstance(System.String) method.

  

  

   typeName: The System.Type.FullName of the type to locate.

   Returns: An instance of System.Object representing the type,with culture,arguments,binder,and 

    activation attributes set to null,and System.Reflection.BindingFlags set to Public or Instance,

    or null if typeName is not found.
  """
  pass
 def Equals(self,other):
  """
  Equals(self: _Assembly,other: object) -> bool

  

   Provides COM objects with version-independent access to the System.Object.Equals(System.Object) 

    method.

  

  

   other: The System.Object to compare with the current System.Object.

   Returns: true if the specified System.Object is equal to the current System.Object; otherwise,false.
  """
  pass
 def GetCustomAttributes(self,*__args):
  """
  GetCustomAttributes(self: _Assembly,inherit: bool) -> Array[object]

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetCustomAttributes(System.Boolean) method.

  

  

   inherit: This argument is ignored for objects of type System.Reflection.Assembly.

   Returns: An array of type Object containing the custom attributes for this assembly.

  GetCustomAttributes(self: _Assembly,attributeType: Type,inherit: bool) -> Array[object]

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetCustomAttributes(System.Type,System.Boolean) method.

  

  

   attributeType: The System.Type for which the custom attributes are to be returned.

   inherit: This argument is ignored for objects of type System.Reflection.Assembly.

   Returns: An array of type System.Object containing the custom attributes for this assembly as specified 

    by attributeType.
  """
  pass
 def GetExportedTypes(self):
  """
  GetExportedTypes(self: _Assembly) -> Array[Type]

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetExportedTypes property.

  

   Returns: An array of System.Type objects that represent the types defined in this assembly that are 

    visible outside the assembly.
  """
  pass
 def GetFile(self,name):
  """
  GetFile(self: _Assembly,name: str) -> FileStream

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetFile(System.String) method.

  

  

   name: The name of the specified file. Do not include the path to the file.

   Returns: A System.IO.FileStream for the specified file,or null if the file is not found.
  """
  pass
 def GetFiles(self,getResourceModules=None):
  """
  GetFiles(self: _Assembly,getResourceModules: bool) -> Array[FileStream]

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetFiles(System.Boolean) method.

  

  

   getResourceModules: true to include resource modules; otherwise,false.

   Returns: An array of System.IO.FileStream objects.

  GetFiles(self: _Assembly) -> Array[FileStream]

  

   Provides COM objects with version-independent access to the System.Reflection.Assembly.GetFiles 

    method.

  

   Returns: An array of System.IO.FileStream objects.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: _Assembly) -> int

  

   Provides COM objects with version-independent access to the System.Object.GetHashCode method.

   Returns: A hash code for the current System.Object.
  """
  pass
 def GetLoadedModules(self,getResourceModules=None):
  """
  GetLoadedModules(self: _Assembly,getResourceModules: bool) -> Array[Module]

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetLoadedModules(System.Boolean) method.

  

  

   getResourceModules: true to include resource modules; otherwise,false.

   Returns: An array of modules.

  GetLoadedModules(self: _Assembly) -> Array[Module]

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetLoadedModules method.

  

   Returns: An array of modules.
  """
  pass
 def GetManifestResourceInfo(self,resourceName):
  """
  GetManifestResourceInfo(self: _Assembly,resourceName: str) -> ManifestResourceInfo

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetManifestResourceInfo(System.String) method.

  

  

   resourceName: The case-sensitive name of the resource.

   Returns: A System.Reflection.ManifestResourceInfo object populated with information about the resource's 

    topology,or null if the resource is not found.
  """
  pass
 def GetManifestResourceNames(self):
  """
  GetManifestResourceNames(self: _Assembly) -> Array[str]

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetManifestResourceNames method.

  

   Returns: An array of type String containing the names of all the resources.
  """
  pass
 def GetManifestResourceStream(self,*__args):
  """
  GetManifestResourceStream(self: _Assembly,name: str) -> Stream

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetManifestResourceStream(System.String) method.

  

  

   name: The case-sensitive name of the manifest resource being requested.

   Returns: A System.IO.Stream representing this manifest resource.

  GetManifestResourceStream(self: _Assembly,type: Type,name: str) -> Stream

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetManifestResourceStream(System.Type,System.String) method.

  

  

   type: The type whose namespace is used to scope the manifest resource name.

   name: The case-sensitive name of the manifest resource being requested.

   Returns: A System.IO.Stream representing this manifest resource.
  """
  pass
 def GetModule(self,name):
  """
  GetModule(self: _Assembly,name: str) -> Module

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetModule(System.String) method.

  

  

   name: The name of the module being requested.

   Returns: The module being requested,or null if the module is not found.
  """
  pass
 def GetModules(self,getResourceModules=None):
  """
  GetModules(self: _Assembly,getResourceModules: bool) -> Array[Module]

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetModules(System.Boolean) method.

  

  

   getResourceModules: true to include resource modules; otherwise,false.

   Returns: An array of modules.

  GetModules(self: _Assembly) -> Array[Module]

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetModules method.

  

   Returns: An array of modules.
  """
  pass
 def GetName(self,copiedName=None):
  """
  GetName(self: _Assembly,copiedName: bool) -> AssemblyName

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetName(System.Boolean) method.

  

  

   copiedName: true to set the System.Reflection.Assembly.CodeBase to the location of the assembly after it was 

    shadow copied; false to set System.Reflection.Assembly.CodeBase to the original location.

  

   Returns: An System.Reflection.AssemblyName for this assembly.

  GetName(self: _Assembly) -> AssemblyName

  

   Provides COM objects with version-independent access to the System.Reflection.Assembly.GetName 

    method.

  

   Returns: An System.Reflection.AssemblyName for this assembly.
  """
  pass
 def GetObjectData(self,info,context):
  """
  GetObjectData(self: _Assembly,info: SerializationInfo,context: StreamingContext)

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetObjectData(System.Runtime.Serialization.SerializationInfo,System.Ru

    ntime.Serialization.StreamingContext) method.

  

  

   info: The object to be populated with serialization information.

   context: The destination context of the serialization.
  """
  pass
 def GetReferencedAssemblies(self):
  """
  GetReferencedAssemblies(self: _Assembly) -> Array[AssemblyName]

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetReferencedAssemblies method.

  

   Returns: An array of type System.Reflection.AssemblyName containing all the assemblies referenced by this 

    assembly.
  """
  pass
 def GetSatelliteAssembly(self,culture,version=None):
  """
  GetSatelliteAssembly(self: _Assembly,culture: CultureInfo,version: Version) -> Assembly

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetSatelliteAssembly(System.Globalization.CultureInfo,System.Version) 

    method.

  

  

   culture: The specified culture.

   version: The version of the satellite assembly.

   Returns: The specified satellite assembly.

  GetSatelliteAssembly(self: _Assembly,culture: CultureInfo) -> Assembly

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetSatelliteAssembly(System.Globalization.CultureInfo) method.

  

  

   culture: The specified culture.

   Returns: The specified satellite assembly.
  """
  pass
 def GetType(self,name=None,throwOnError=None,ignoreCase=None):
  """
  GetType(self: _Assembly,name: str,throwOnError: bool) -> Type

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetType(System.String,System.Boolean) method.

  

  

   name: The full name of the type.

   throwOnError: true to throw an exception if the type is not found; false to return null.

   Returns: A System.Type object that represents the specified class.

  GetType(self: _Assembly,name: str,throwOnError: bool,ignoreCase: bool) -> Type

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetType(System.String,System.Boolean,System.Boolean) method.

  

  

   name: The full name of the type.

   throwOnError: true to throw an exception if the type is not found; false to return null.

   ignoreCase: true to ignore the case of the type name; otherwise,false.

   Returns: A System.Type object that represents the specified class.

  GetType(self: _Assembly) -> Type

  

   Provides COM objects with version-independent access to the System.Object.GetType method.

   Returns: A System.Type object.

  GetType(self: _Assembly,name: str) -> Type

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.GetType(System.String) method.

  

  

   name: The full name of the type.

   Returns: A System.Type object that represents the specified class,or null if the class is not found.
  """
  pass
 def GetTypes(self):
  """
  GetTypes(self: _Assembly) -> Array[Type]

  

   Provides COM objects with version-independent access to the System.Reflection.Assembly.GetTypes 

    method.

  

   Returns: An array of type System.Type containing objects for all the types defined in this assembly.
  """
  pass
 def IsDefined(self,attributeType,inherit):
  """
  IsDefined(self: _Assembly,attributeType: Type,inherit: bool) -> bool

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.IsDefined(System.Type,System.Boolean) method.

  

  

   attributeType: The System.Type of the custom attribute to be checked for this assembly.

   inherit: This argument is ignored for objects of this type.

   Returns: true if a custom attribute identified by the specified System.Type is defined; otherwise,false.
  """
  pass
 def LoadModule(self,moduleName,rawModule,rawSymbolStore=None):
  """
  LoadModule(self: _Assembly,moduleName: str,rawModule: Array[Byte],rawSymbolStore: Array[Byte]) -> Module

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.LoadModule(System.String,System.Byte[],System.Byte[]) method.

  

  

   moduleName: Name of the module. Must correspond to a file name in this assembly's manifest.

   rawModule: A byte array that is a COFF-based image containing an emitted module,or a resource.

   rawSymbolStore: A byte array containing the raw bytes representing the symbols for the module. Must be null if 

    this is a resource file.

  

   Returns: The loaded module.

  LoadModule(self: _Assembly,moduleName: str,rawModule: Array[Byte]) -> Module

  

   Provides COM objects with version-independent access to the 

    System.Reflection.Assembly.LoadModule(System.String,System.Byte[]) method.

  

  

   moduleName: Name of the module. Must correspond to a file name in this assembly's manifest.

   rawModule: A byte array that is a COFF-based image containing an emitted module,or a resource.

   Returns: The loaded Module.
  """
  pass
 def ToString(self):
  """
  ToString(self: _Assembly) -> str

  

   Provides COM objects with version-independent access to the System.Reflection.Assembly.ToString 

    method.

  

   Returns: The full name of the assembly,or the class name if the full name of the assembly cannot be 

    determined.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __str__(self,*args):
  pass
 CodeBase=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.Assembly.CodeBase property.



Get: CodeBase(self: _Assembly) -> str



"""

 EntryPoint=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.Assembly.EntryPoint property.



Get: EntryPoint(self: _Assembly) -> MethodInfo



"""

 EscapedCodeBase=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.Assembly.EscapedCodeBase property.



Get: EscapedCodeBase(self: _Assembly) -> str



"""

 Evidence=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.Assembly.Evidence property.



Get: Evidence(self: _Assembly) -> Evidence



"""

 FullName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.Assembly.FullName property.



Get: FullName(self: _Assembly) -> str



"""

 GlobalAssemblyCache=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.Assembly.GlobalAssemblyCache property.



Get: GlobalAssemblyCache(self: _Assembly) -> bool



"""

 Location=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.Assembly.Location property.



Get: Location(self: _Assembly) -> str



"""


 ModuleResolve=None

